Search changeset comments
Source:R/osmapi_changeset_discussion.R
osm_search_comment_changeset_discussion.RdReturns changeset comments that match the specified query. If no query is provided, the most recent changeset comments are returned.
Usage
osm_search_comment_changeset_discussion(
user,
from,
to,
format = c("R", "xml", "json"),
tags_in_columns = FALSE
)Arguments
- user
Search for changeset comments created by the user with the given user id (numeric) or display name (character).
- from
Beginning date range. See details for the valid formats.
- to
End date range. Only works when
fromis supplied. See details for the valid formats.- format
Format of the output. Can be
"R"(default),"xml", or"json".If
FALSE(default), the tags of the changesets are saved in a single list columntagscontaining adata.framefor each changeset with the keys and values. IfTRUE, add a column for each key. Ignored ifformat != "R".
Value
If format = "R", returns a data frame with one comment per If format = "xml", returns a
xml2::xml_document. If format = "json", returns a list with the json structure.
Details
The valid formats for from and to parameters are POSIXt values or characters preferably in
ISO 8601 format.
See also
Other changeset discussion's functions:
osm_comment_changeset_discussion(),
osm_hide_comment_changeset_discussion(),
osm_subscribe_changeset_discussion()
Examples
# See the latest changeset comments globally:
osm_search_comment_changeset_discussion()
#> id date visible uid user
#> 1 1661292 2026-09-15 18:26:17 TRUE 23486970 Tanchoteac
#> 2 1661291 2026-09-15 18:20:25 TRUE 21392280 CAM-Gerlach
#> 3 1661290 2026-09-15 18:19:39 TRUE 23057692 gjward
#> 4 1661289 2026-09-15 18:18:59 TRUE 24572 sly
#> 5 1661288 2026-09-15 18:17:51 TRUE 8610651 easy_go
#> 6 1661287 2026-09-15 18:16:41 TRUE 18137286 Linus W Frische
#> 7 1661286 2026-09-15 18:16:16 TRUE 3102814 ZdenSvk
#> 8 1661285 2026-09-15 18:14:07 TRUE 3997418 Alikam
#> 9 1661284 2026-09-15 18:09:01 TRUE 10833953 Colbertson
#> 10 1661283 2026-09-15 18:07:59 TRUE 16885157 Anonymous897234
#> 11 1661282 2026-09-15 18:04:34 TRUE 242345 confusedbuffalo
#> 12 1661281 2026-09-15 17:59:12 TRUE 3951648 rskedgell
#> 13 1661280 2026-09-15 17:58:59 TRUE 19837576 Awoobis
#> 14 1661279 2026-09-15 17:57:57 TRUE 19837576 Awoobis
#> 15 1661278 2026-09-15 17:57:14 TRUE 19837576 Awoobis
#> 16 1661277 2026-09-15 17:56:53 TRUE 5064615 rempshaener
#> 17 1661276 2026-09-15 17:56:35 TRUE 11912345 UNGSC-Jrachi
#> 18 1661275 2026-09-15 17:56:30 TRUE 496201 Nakaner
#> 19 1661274 2026-09-15 17:55:45 TRUE 496201 Nakaner
#> 20 1661273 2026-09-15 17:53:05 TRUE 2339960 adrianojbr
#> 21 1661272 2026-09-15 17:52:08 TRUE 15834339 yitimox
#> 22 1661271 2026-09-15 17:51:06 TRUE 21876711 Nadja15
#> 23 1661270 2026-09-15 17:49:44 TRUE 61942 SomeoneElse
#> 24 1661269 2026-09-15 17:49:31 TRUE 61942 SomeoneElse
#> 25 1661268 2026-09-15 17:48:54 TRUE 19743347 Sylabowy Kot
#> 26 1661267 2026-09-15 17:47:31 TRUE 242345 confusedbuffalo
#> 27 1661266 2026-09-15 17:47:21 TRUE 21876711 Nadja15
#> 28 1661265 2026-09-15 17:47:11 TRUE 19743347 Sylabowy Kot
#> 29 1661264 2026-09-15 17:46:41 TRUE 4289510 aq123
#> 30 1661263 2026-09-15 17:46:15 TRUE 334075 eggie
#> 31 1661262 2026-09-15 17:44:29 TRUE 11912345 UNGSC-Jrachi
#> 32 1661261 2026-09-15 17:38:47 TRUE 6793422 Sangueffusor
#> 33 1661260 2026-09-15 17:35:15 TRUE 496201 Nakaner
#> 34 1661259 2026-09-15 17:34:49 TRUE 14505749 NaufalFarras
#> 35 1661258 2026-09-15 17:34:46 TRUE 496201 Nakaner
#> 36 1661257 2026-09-15 17:26:03 TRUE 10626847 SK@
#> 37 1661256 2026-09-15 17:25:22 TRUE 5064615 rempshaener
#> 38 1661255 2026-09-15 17:25:09 TRUE 10626847 SK@
#> 39 1661254 2026-09-15 17:24:56 TRUE 169989 Sakari_N
#> 40 1661253 2026-09-15 17:21:23 TRUE 10626847 SK@
#> 41 1661252 2026-09-15 17:15:14 TRUE 5064615 rempshaener
#> 42 1661251 2026-09-15 17:08:28 TRUE 6250193 Kovoschiz
#> 43 1661250 2026-09-15 17:07:56 TRUE 379467 osmviborg
#> 44 1661249 2026-09-15 17:05:40 TRUE 23157620 journeyman317
#> 45 1661248 2026-09-15 17:02:59 TRUE 21833106 LingM
#> 46 1661247 2026-09-15 17:00:45 TRUE 5064615 rempshaener
#> 47 1661246 2026-09-15 16:59:01 TRUE 23486970 Tanchoteac
#> 48 1661245 2026-09-15 16:58:03 TRUE 14505749 NaufalFarras
#> 49 1661244 2026-09-15 16:57:15 TRUE 20637388 Kugelbaum
#> 50 1661243 2026-09-15 16:57:05 TRUE 24557246 cdesbranches
#> 51 1661242 2026-09-15 16:56:32 TRUE 24557246 cdesbranches
#> 52 1661241 2026-09-15 16:55:59 TRUE 24550275 moxaq
#> 53 1661240 2026-09-15 16:55:35 TRUE 24550275 moxaq
#> 54 1661239 2026-09-15 16:50:15 TRUE 23968956 JMJB
#> 55 1661238 2026-09-15 16:48:45 TRUE 23968956 JMJB
#> 56 1661237 2026-09-15 16:47:28 TRUE 334075 eggie
#> 57 1661236 2026-09-15 16:46:51 TRUE 3951648 rskedgell
#> 58 1661235 2026-09-15 16:41:43 TRUE 23968956 JMJB
#> 59 1661234 2026-09-15 16:35:03 TRUE 17687710 xSophiee
#> 60 1661233 2026-09-15 16:32:16 TRUE 16653745 CanopyFalls
#> 61 1661232 2026-09-15 16:30:00 TRUE 21888737 Sébastien Pi
#> 62 1661231 2026-09-15 16:25:26 TRUE 24553609 Woldumar
#> 63 1661230 2026-09-15 16:24:18 TRUE 5800005 b-jazz
#> 64 1661229 2026-09-15 16:19:50 TRUE 21834975 sajjad_samaei
#> 65 1661228 2026-09-15 16:18:16 TRUE 16653745 CanopyFalls
#> 66 1661227 2026-09-15 16:18:11 TRUE 9450913 Berlin53
#> 67 1661226 2026-09-15 16:17:14 TRUE 16653745 CanopyFalls
#> 68 1661225 2026-09-15 16:12:32 TRUE 16653745 CanopyFalls
#> 69 1661224 2026-09-15 16:11:02 TRUE 16653745 CanopyFalls
#> 70 1661223 2026-09-15 16:10:50 TRUE 334075 eggie
#> 71 1661222 2026-09-15 16:06:41 TRUE 16653745 CanopyFalls
#> 72 1661221 2026-09-15 16:06:21 TRUE 14505749 NaufalFarras
#> 73 1661220 2026-09-15 16:04:29 TRUE 10564232 RedfishTheCat
#> 74 1661219 2026-09-15 15:59:45 TRUE 10080656 dcapillae
#> 75 1661218 2026-09-15 15:59:30 TRUE 10080656 dcapillae
#> 76 1661217 2026-09-15 15:51:56 TRUE 22861382 Matthew Vennik
#> 77 1661216 2026-09-15 15:50:06 TRUE 17285979 MaliMrav
#> 78 1661215 2026-09-15 15:49:38 TRUE 10080656 dcapillae
#> 79 1661214 2026-09-15 15:48:59 TRUE 17285979 MaliMrav
#> 80 1661213 2026-09-15 15:48:37 TRUE 10080656 dcapillae
#> 81 1661212 2026-09-15 15:46:53 TRUE 334075 eggie
#> 82 1661211 2026-09-15 15:41:31 TRUE 334075 eggie
#> 83 1661210 2026-09-15 15:40:30 TRUE 5164 woodpeck
#> 84 1661209 2026-09-15 15:40:24 TRUE 334075 eggie
#> 85 1661208 2026-09-15 15:38:22 TRUE 17800352 Userinexile
#> 86 1661207 2026-09-15 15:35:25 TRUE 16653745 CanopyFalls
#> 87 1661206 2026-09-15 15:34:54 TRUE 334075 eggie
#> 88 1661205 2026-09-15 15:33:56 TRUE 564990 mavl
#> 89 1661204 2026-09-15 15:33:11 TRUE 20144444 MappingMore
#> 90 1661203 2026-09-15 15:32:52 TRUE 21330644 Jagged DeepPink Echidna
#> 91 1661202 2026-09-15 15:30:54 TRUE 334075 eggie
#> 92 1661201 2026-09-15 15:27:39 TRUE 334075 eggie
#> 93 1661200 2026-09-15 15:24:31 TRUE 334075 eggie
#> 94 1661199 2026-09-15 15:23:46 TRUE 334075 eggie
#> 95 1661198 2026-09-15 15:19:22 TRUE 2859698 assanges
#> 96 1661197 2026-09-15 15:18:19 TRUE 2859698 assanges
#> 97 1661196 2026-09-15 15:12:17 TRUE 6466263 zorglubu
#> 98 1661195 2026-09-15 15:09:46 TRUE 16653745 CanopyFalls
#> 99 1661194 2026-09-15 15:03:41 TRUE 2274390 dzidek23
#> 100 1661193 2026-09-15 15:02:57 TRUE 20144444 MappingMore
#> comment_text
#> 1 I see in the girds: A comment stating " Task for project 65055. Do not edit outside of this area! As a result I do not go outside of the magenta lines. " I cannot figure out the problem. I am placing the tags but cannot figure out the incomplete tags.
#> 2 Thanks!\n\nJust FYI, though, I see operator:wikipedia=* wasn't updated to match operator=* and operator:wikidata=*; since there isn't a Wikipedia page specific to VT Libraries, should it just be removed?
#> 3 I see it now! I couldn't find it in the changese. I'm still relatively new to OSM, and still learning.\n\nNow I'm curious about the history of the course. In my 20 years of living in the area, I've never heard of it. I wonder when it closed. Time for some investigation.
#> 4 ha ben oui, zut, je ne devais pas avoir les yeux en face des trous j'ai rien vu de la 2ème moitié de ton message.\n\nMerci pour l'info, en cumulant avec les infos d'une autre photo+exif (posée sur refuges.info) je pense avoir maintenant confirmation à ~5m de la position, avec un peu d'imagination, je place ça sous l'arbre le plus proche et ça ira bien. Merci !
#> 5 Hello Sam Jayah, the user that added this ref=NJ051 tagging to (https://www.openstreetmap.org/way/108535182) is no longer active. If you have a resource that shows this ref tagging is incorrect, I would be happy to review this. Thank you and happy mapping!
#> 6 Nej, bygningerne på skolegrunden og ved svømmehallen er der stadig. Skolen står dog ubrug hen og er en ruin (dermed brownfield), mens svømmehallen stadig er skadet efter branden (deraf damaged:building). \n\nHvorfor spørger du om det? Du har stadig ikke svaret på hvorfor du lavede din ændring.
#> 7 Ahoj,\n\nďakujem za komentár. Rozumiem čo chceš povedať, moja logika bola nasledujúca.\n\n- Ide o značenú cyklotrasu, nie turistický chodník. Cyklotrasa má označenie jednosmernej jazdy\n- Bez tejto informácie je rozbité trasovanie pre cyklistov, ktorých môže poslať do protismeru. Je pravda, že dole nie je ceduľa že cyklista ide do protismeru.\n\n-Nemal by byť problém pre turistu. Toho vytrasuje aj v jednosmerke. Chodník ale nie je značený ako turistický.\n\n- Priznám, že na chatárov som nemyslel. \n\nViem si predstaviť ponechať oneway na úseku medzi rázcestníkom ihelník a miestom, kde sa trail napojí na cesty, ktoré využívajú aj chatári.\n\ntag mtb:scale:uphill=2 nepoznám, neviem ako to následne prenesie do máp.\n
#> 8 Merhabalar, yani bir yıl önce yapılmış bir değişikliği neden yaptığımı hatırlamıyorum. Bahsettiğiniz gerekçelerle ve planlarla ilgili durak düzenlemelerini yapabilirsiniz. İyi çalışmalar
#> 9 atcēlu šīs izmaiņas\nnoņemt highway=service ir nepareizi\nja jūsu maršrutētājam ir problēmas tās ir jārisina ar maršrutētāju nevis ar greiziem OSM datu labojumiem
#> 10 Any idea if the airport is always equally shifted relative to the city?\n\nIs there historical GPS locations for the airport (runway / tower / any part)? If so, we can compare the relative movement, as there is historical locations for the city.\n\nI'm wondering if we can always just shift the airport along with the city.
#> 11 Hi, it had some use and seemed to fit these cases well. I had been going to document it, so I guess this is my nudge to do so. I haven't added an image yet, but have put a link to an example of one.
#> 12 Welcome to OpenStreetMap.\n\nYou have removed the building=transportation tag from a feature which appears to be a building. What were you trying to do here?\n\nAlso, please could you write meaningful changeset comments? I can't see what "welcome to cancun Quintana roo Mexico" could have to do with a park & ride facility outside Oxford, GB
#> 13 Nie idzie sensownie zostawić śladu w osm że tutaj był lokal o X nazwie (jest spory znak).\n\nZmiany przedstawiają stan faktyczny.
#> 14 https://www.openstreetmap.org/changeset/189070410
#> 15 Skądś się to wzieło, a zapobiegnie to ponownemu dodaniu nieistniejącego przejścia.\n\nDe facto z drugiej strony budynku tj od dziedzińca nie wiem co jest bo tylko od zewnątrz obszedłem. Może nic, może wejście na klatkę
#> 16 Hallo,\ndas horse=no stammt von mir, weil es nun mal leider so ausgeschildert ist.\nNur noch einmal zur Verdeutlichung: Die Beschilderungen sind unschön, aber rechtlich okay. Z. B. für den nördlichen Teil: Aus der einen Richtung verhindert das Verkehrszeichen 240 das Reiten, aus der anderen das Vz 257-51. Aus dieser Richtung wird das Befahren mit Kraftfahrzeugen durch physische Sperren oder vorgeschaltete Vz 250 auf den Zufahrten verhindert. Also nicht falsch, sondern nur ungewöhnlich. \nDas foot=yes und bicycle=yes (und auch horse=yes) gilt an highway=path immer. Genau wie motor_vehicle=no, siehe https://wiki.openstreetmap.org/wiki/DE:Tag:highway%3Dpath. Das übersteuert auch das access=yes. Das taggen wir deswegen ja auch nicht. Ein highway=path ist in der Regel ausreichend.\nInsofern verstehe ich den Hinweis auf Rendering und Routing nicht wirklich. Kein Router dürfte PKW über diese Strecke schicken. Fahrradrouter können über die Strecke schicken, sofern das surface=compacted nicht daran hindert.\nAlso mal davon abgesehen, dass wir in der Regel die tatsächliche rechtliche Situation abbilden: was ist denn hier deiner Meinung nach falsch?\nViele Grüße
#> 17 Ciao.\nQuel percorso ha dei problemi con l'erba alta che rendono difficile l'individuazione della traccia.\nEsiste una segnaletica verticale ad inizio e fine, e sono state posti numerosi segni bianco-rossi lungo il percorso.\nSi tratta di un percorso presente nel catasto regionale e non dovevi cancellarlo.\nLo ripristino e ti prego di mettere i tag corretti sui tratti dove il trail_visibiltyt è scarso o insufficiente.\n\nGrazie di mappare!\n\nIvo
#> 18 Hallo Lehte,\n\nzu diesem Änderungssatz steht noch eine Stellungnahme aus. Sollte diese ausbleiben, werde ich nach eigenem Ermessen über die Änderung entscheiden.\n\nViele Grüße\n\nMichael
#> 19 Hallo,\n\nwarum hast du in diesem Änderungssatz access=destination gesetzt, obwohl Rad- und Reitverkehr uneingeschränkt, zudem auch landwirtschaftlicher Kfz-Verkehr zulässig ist? https://www.mapillary.com/app/?lat=48.9993135&lng=8.824289399999998&z=17&pKey=1389856159123583&focus=photo&x=0.48610185596942523&y=0.5162188998656347&zoom=1.2815533980582523\n\nViele Grüße\n\nMichael
#> 20 Boa tarde, James. Você pode me enviar cópia da notificação que você recebeu (adrianojbr@gmail.com), com a devida ocultação de dados sensíveis, claro?\n\nNão estou duvidando da sua afirmação, mas quero entender melhor essa questão de validação do Inmetro. Até onde sei, se o radar não está validado pelo Inmetro, não pode gerar multa. Nas notificações que recebi, inclusive, vem a informação da verificação do Inmetro. Talvez seja o caso de deixar de confiar nos dados site do Inmentro.\n ---\n \n Published using OSMCha: https://osmcha.org/changesets/186786452\n
#> 21 Ali hocam, bu düzenlemenizde Edirnekapı Minibüs Duraklarını neden kaldırdığınızı öğrenebilir miyim? Minibüsler ara duraklarda İETT ile ortak kullanmak zorunluluğundayken başlangıç ve varış noktaları bunlardan bağımsızdır ve "D" işaretli tabelalarla belirtilir. Edirnekapı'da tramvay istasyonunun tam üstünde bu şekilde durak mevcut ve gelecekte suriçindeki durak bütünüyle kapatılıp tüm Edirnekapı araçlarının buradan kaldırılması planlanıyor
#> 22 I think there is a bridleway alongside the walkway. The bridleway is just a dirt path, not asphalt path.
#> 23 Üdv Szerkesztő!\n\nSok felhasználó tett fel neked kérdéseket a változáskészleteiddel kapcsolatban. Ezeket a kérdéseket e-mailben elküldtük neked, és a https://resultmaps.neis-one.org/osm-discussion-comments?uid=2479157 címen is megtekintheted őket.\n\nKérlek, válaszolj - kattints át a változáskészletre, és írj egy hozzászólást.\n\nÜdvözlettel,\n\nAndy Townsend, az OSM adatmunkacsoportja nevében.
#> 24 Hello Szerkesztő,\n\nLots of users have asked you questions about your changesets. These questions will have been emailed to you and you can also see them at https://resultmaps.neis-one.org/osm-discussion-comments?uid=2479157 .\n\nPlease do reply - click through to the changeset and add a comment in reply.\n\nBest Regards,\n\nAndy Townsend, on behalf of OSM’s data working group.
#> 25 Nie rozumiem. disused:shop jest właśnie dla oznaczania pustostanów po poprzednim zagospodarowaniu lokalu (bo lokal usługowy istnieje, jak budynek stoi) a ty skasowałeś zarówno istniejący sklep, jak i nieaktualny.
#> 26 Wow, no idea how I managed that, thanks very much for noticing. Should be all fixed in https://www.openstreetmap.org/changeset/189074578
#> 27 Jag tror faktiskt det går en ridväg där precis längsmed den asfalterade gångvägen.
#> 28 Jeśli nie ma wejścia do budynku od Brechta a tylko od dziedzińca, to lepiej zmienić to istniejące na entrance, a korytarz w budynku usunąć, a nie robić takiego potworka jak not:highway - co to jest w takim razie?
#> 29 Проверил. Нет там почты\n ---\n \n Published using OSMCha: https://osmcha.org/changesets/188977618\n
#> 30 Hi,\n\nPlease use the present addressnode to tag on. Addr:city?\nGr eggie
#> 31 Ciao.\nPerché hai aggiunto un name fittizio?\nIl ref è nella relazione e identifica il percorso non i tratti di strada che lo compongono.\n\nIvo
#> 32 That may also be true, but that's still not the one that I marked as abandoned, which is/was located on CR 750 E inbetween E 200 S and E 300 S.
#> 33 Ich habe highway=tertiary in changeset/189073901 wiederhergestellt.
#> 34 This is based on local knowledge. This change is also supported by the fact that Jalan Mayjend Sungkono on the west is classified as arterial until it ends in Jembatan Brawijaya junction, which creates an dead end of the primary highway network. Changing P.K. Bangsa-Diponegoro corridor would solve this issue.\n\nJalan Dhoho and Yos Sudarso could also be changed into highway=primary based on activities and traffic in those streets. However, to preserve status-quo and the fact that this corridor is narrower than other intracity primary corridors, it would be better to use highway=secondary for them right now, awaiting newer regulatory classification.
#> 35 reverted by changeset/189073901
#> 36 Thank you for fixing it! I am usually trying to make buildings NOT spiky so it is an unfortunate mistake that I did create one myself. Appreciate your care.
#> 37 Hallo,\nin dem Änderungssatz hast du die Straßenbahnhaltestelle Berliner Allee um rund 800 m verschoben. Ich musste deine Änderung zurücksetzen.\nViele Grüße
#> 38 I did respond to the message I was sent privately and have not touched buildings in Brussels since. Just adding the comment here as I am reviewing any unanswered comments on my changesets from the past. Thanks.
#> 39 Moi, ja tervetuloa muokkaamaan OSM:aa! \n\nHyvä havainto nopeurajoituksesta. Korjasin toteutusta niin, että tie on yksi viiva (kuten ennen) ja lisäsin nopeusrajoitukset tageilla maxspeed:backward=50 ja maxspeed:forward=80. \n\nTie on yksi viiva, koska kaistoja ei ole fyysisesti erotettu toisistaan. Ja nämä forward ja backward ovat eteen- ja taaksepäin ns. viivan suuntaan. Viivan suunnan näkee editorissa, viivassa on pienet nuolet jotka kuvaavat tätä.
#> 40 I don't disagree but I can tag that it is a church and what type but I don't know the name...so I didn't change it/remove what can't really be a church name is more type of church - I assume they meant Roman Catholic Church. Thanks Enock.
#> 41 Hallo,\nwas ist der Grund dieser Änderung?\nLass mich raten: "Meistens wird nur das "opening_hours" Tag ausgewertet und alles mit einem Subkey ist nicht sichtbar. Jetzt stehen die wichtigsten Informationen direkt im Haupttag und sind damit für wesentlich mehr Anwender verfügbar."?\nViele Grüße
#> 42 `=unclassified` means minor road from UK, not undefined. `=residential` is used for local streets not mainly for through traffic.
#> 43 Er bygninger fjernet?
#> 44 It's okay, no need to revert changeset, I have manually renamed affected roads to their correct names. Thanks
#> 45 Danke für die schnelle Korrektur.
#> 46 Hallo,\nwas war denn hier falsch?\nViele Grüße
#> 47 I am following through with the process but I have to check to see what is happening. I had similar problems with photomappers. If they are missing, i will go back and fix it. Please give me example and I can compare on my side. Thomas
#> 48 Mohon baca dulu Panduan Penandaan di situs web OSM Wiki. Klasifikasi jalan tidak ditentukan hanya dengan kewenangan jalan.
#> 49 Hello again SHARCRASH (I very strongly assume),\n\nWhat are your sources for newly added paths/tracks in this area? Way 1558319175 oddly fits very thin Strava heatmap and lidar imagery.
#> 50 j'aimerais que cette modification soit annulée
#> 51 j'aimerais que cette modification soit annulée \nje suis trop novice
#> 52 Apologies, @CanopyFalls not @/CanpoyFalls!
#> 53 Hi @CanpoyFalls, thank you for taking a look! The signs through the edited paths say "No Cycling, local byelaws apply", though I was unsure whether those should be marked as bicycles=no or bicycles=dismount :-)
#> 54 Reverting road changes without reasoning constitutes vandalism. There is no reasoning for Secondary road classification, the road does not link towns or primary roads as per OpenStreetMap guidelines.
#> 55 Reverting road changes without reasoning constitutes vandalism. Road 603 does not exist within Prague.
#> 56 Oke.. duidelijk.\nMvg,\neggie
#> 57 It might be worth splitting the track ( https://www.openstreetmap.org/way/636382615 ) at the gate and tagging the part inside as access=private as well.
#> 58 Reverting road changes without reasoning is against OpenStreetMap guidelines and constitutes vandalism.
#> 59 Mijn bron is dat ik daar elke dag 4x overheen rij. De wegen zullen vast privegrond zijn, maar zijn gewoon openbare wegen. De bedrijven zelf zitten wel achter hekken.
#> 60 Looks good aside from the capacity being listed as 14 when it seems like it's 12 from satellite imagery and your own edit.\n ---\n #REVIEWED_GOOD #OSMCHA\n Published using OSMCha: https://osmcha.org/changesets/189067801\n
#> 61 Bonjour M. Jouglet,\n\nConcernant https://www.openstreetmap.org/relation/17757675 et vu https://www.openstreetmap.org/note/5462155, savez-vous s’il est prévu de déplacer la Vélo+ 1b par l’avenue Le Nôtre à terme ?
#> 62 Thank you for the lesson. I'll take a look at the changes and see what I can do that's more in line with these policies. Some of the trails are former trails that are now completely naturalized. There's one that's a meandering line through the woods where no trail has ever existed. Fire pits were removed 12 years ago and starting a fire on this property is considered an act of trespassing, so I'll note that on these features.
#> 63 You have made a common error when you saw a fairway that looked like it didn't have a proper "Feature Type" defined and decided to add the fairway tag. The hole was already properly tagged, but was part of a relation of multiple objects known as a multipolygon. Please read this short wiki page where I've tried to explain what you are looking at and avoid making the mistake in the future. https://wiki.openstreetmap.org/wiki/ID_understanding_golf_course_relations Thanks.\n
#> 64 سلام\nلطفا در ادیت نقشه دقت کنید
#> 65 Looks good! Ta for contributing to the map!\n ---\n #REVIEWED_GOOD #OSMCHA\n Published using OSMCha: https://osmcha.org/changesets/188978577\n
#> 66 Der offizielle Name ist immer noch "Bundesautobahn 12". Wikipedia verwendet den Begriff Beinamen für "Autobahn der Freiheit". Da würde vielleicht alt_name noch besser passen. Lt. Wiki sollte das Objekt mit seinem Namen auch in der Realität zu finden sein. Dies ist jedenfalls zur Zeit nicht der Fall.
#> 67 Just to check is it signed for cyclists to dismount or as an exclusively pedestrian area? I believe the byelaws in London only exclude cycling if it is signed as such. That aside the changes look correct! TY for contributing to the map and welcome to OSM!\n ---\n #REVIEWED_GOOD #OSMCHA\n Published using OSMCha: https://osmcha.org/changesets/188984080\n
#> 68 Nice additions to the tags! If you plan on adding more details to your local area cannot recommend the app Street Complete highly enough if you have android.\n ---\n #REVIEWED_GOOD #OSMCHA\n Published using OSMCha: https://osmcha.org/changesets/189015256\n
#> 69 Looks good! Ta for taking the time to contribute to the map and welcome to OSM!\n ---\n #REVIEWED_GOOD #OSMCHA\n Published using OSMCha: https://osmcha.org/changesets/189015826\n
#> 70 phone \t+31 20 820 8127\nen de website =https://bongusta.nl staan er nog in. Wellicht geen upload gedaan?\n\nGr eggie
#> 71 Changeset looks good! This area could do with some more refinement like adding the service road next to the footway and applying the `access=private` to the section of footway after the gate as well but the changes made are good! TY for contributing to the map!\n ---\n #REVIEWED_GOOD #OSMCHA\n Published using OSMCha: https://osmcha.org/changesets/189017592\n
#> 72 Sorry I typed wrong relation ID. I will revert it back later. Thank you
#> 73 J'ai donné les données GPS de la photo dans mon message précédent. ^^\n"Les coordonnées de ma photo indiquent 44, 54' 52.000000" nord et 5, 31' 22.000000" est. Ce qui semble indiquer la fontaine de Berrièves. Mais avec la marge d'erreur, ce n'est pas certain. "
#> 74 Si lo que se desea es indicar que la vía de servicio es transitable a pie, no hay problema: la vía en OSM está etiquetada con «foot=yes», lo que indica a los enrutadores que se puede recorrer a pie como si fuera una senda peatonal.
#> 75 Si lo que se desea es indicar que la vía de servicio es transitable a pie, no hay problema: la vía en OSM está etiquetada con «foot=yes», lo que indica a los enrutadores que se puede recorrer a pie como si fuera una senda peatonal.
#> 76 Ja openingstijden zijn hetzelfde gebleven. Telefoonnummer had ik verwijderd omdat ze deze ook niet op hun website vermelden. Het was een toko/snackbar en is nu een snackbar.
#> 77 OSM Wiki link was incorrect, let me try one more time:\n\nhttps://wiki.openstreetmap.org/wiki/Key:opening_hours
#> 78 Hola.\n\nEste cambio fue revertido. Las razones se explican en un anterior conjunto de cambios: changeset/188611661\n\nEsta vía es un camino de entrada de vehículos, señalizado con vado. Lo usan los clientes y los taxis para acceder con vehículo a la entrada del hotel y al garaje. Verificado sobre el terreno.\n\nUn cordial saludo,\n\nDaniel Capilla
#> 79 Hello DrSlauman,\n\nFirst, kudos for making changes and additions on OSM map, I appreciate it.\n\nIf you don't mind, let me point out to couple of mistakes you made:\n\nAbbreviations in opening_hours tag should be in English. So the value you entered for different amenities, like "Klub Txe Dvorište Subotica":\n\nПн-Чт 17:00-00:00, Пт-Сб 17:00-02:00\n\nis incorrect. It should be:\n\nMo-Th 17:00-00:00, Fr-Sa 17:00-02:00\n\nYou can use validator here to check for correctness:\n\nhttps://openingh.openstreetmap.de/evaluation_tool/\n\nAnd you can read (rather long) OSM Wiki page here:\n\nhttps://wiki.openstreetmap.org/wiki/Key:opening hours\n\nAlso, regarding the name of that particular club, you can read proper naming sugestions here:\n\nhttps://wiki.openstreetmap.org/wiki/Names\n\nIf "Subotica" and "Klub" is not part of the name then it should not be in the "name" tag. \n\nIf "The" is written in Latin script on the enterenace (I don't know, I just checked their Facebook page where "The" is indeed written in Latin script), then you should not write in in Cyrillic.\n\nHappy Mapping,\nMaliMrav
#> 80 Hola. \n\nEste cambio fue revertido. Las razones se explican en un anterior conjunto de cambios: https://www.openstreetmap.org/changeset/188611661\n\nEsta vía es un camino de entrada de vehículo, señalizado con vado. Lo usan los clientes y los taxis para acceder con vehículo a la entrada del hotel. Verificado sobre el terreno.\n\nUn cordial saludo,\n\nDaniel Capilla
#> 81 Dag Matthew.. Een naam kan veranderen. Je hebt de voorgaande website laten staan. \nKloppen de openingstijden en het telefoonnummer nog?\nJe geeft niet aan bij je upload wat je hebt aangepast.\nMVG\neggie
#> 82 Welkom bij OpenStreetMap. Ik heb een uitgebreid welkomstbericht met wat handige tips en links gestuurd als privebericht.\nMVG,\nEggie\nNamens de OSM Community\n\n\n
#> 83 We have two different parties each claiming conflicting signage. One party claims "Signage posted in June 2026 said the trail is ridable with construction works on-going" and the other party claims "Signage posted in 2026 said the trail is cancelled". I want to know whether both refer to the same sign (and just read the sign differently), or whether there are conflicting signs, or whether one party has maybe put up their own self-made sign, or whether one party is perhaps outright lying. Photos of the signs would be a good first step to find out what is really going on, who is trustworthy and who is creative with the truth.
#> 84 De winkel heb ik verplaatst naar de nieuwe locatie.
#> 85 但是这里它就是南边步道的延续
#> 86 Hello! Thank you for contributing to the map and welcome to osm!\n\nUnfortunately I've reviewed this as bad on OSMCha. `highway=cycleway` is for dedicated cycle infrastructure. this seems more like `highway=service` if it only serves as access to a single or a few residential properties.\n\nI would also like to check that the combination of `access=private`, `foot=yes` and `bicycle=yes` is correct and verifiable as this would seem to suggest that the road is signed as private property with no access except for those on foot or using a bike. If the road isn't signed as private property then access is still public regardless of the ownership of the road. It would also need to explicitly include foot and bike traffic which seems unlikely.\n\nI've not made any changes but am happy to implement any fixes if you don't want to.\n\nThank you for your time and attention mapping! Feel free to reply if you have any questions and best of luck with future mapping!\n ---\n #REVIEWED_BAD #OSMCHA\n Published using OSMCha: https://osmcha.org/changesets/189064619\n
#> 87 Welkom bij OpenStreetMap. Ik heb een uitgebreid welkomstbericht met wat handige tips en links gestuurd als privebericht.\n\nFeedback.. Hoe kan nu een adres aan de Berenstraat veranderen in de Geldese Kade?\nIn OSM gaat dan niet een bedrijf naar een andere locatie. Je zult op de nieuwe locatie op de juiste adresnode de winkel moeten toevoegen en hier alleen de winkelinfo verwijderen. \nMVG,\nEggie\nNamens de OSM Community\n\n
#> 88 Здравствуйте. Подскажите, почему вы думаете, что источником адреса является ЕГРН? \n \nПочему источником адреса не является табличка с адресом на здании?
#> 89 Reverted in https://www.openstreetmap.org/changeset/189067756
#> 90 Hi everyone, thank you for taking the time to review the changes and to revert the incorrect ones.\n\nIn regards to the Painted markings, on the position 52.5270987 / 1.4960007 there is a slip road joining the A146. It would be appropriate to add a parallel trunk link connecting at the end where the slip road ends? or the tertiary road is enough?
#> 91 De importnodes liggen gewoon als een stapeltje op elkaar.\nDus niet naar de kaart kijken of je huisnummer erbij zit. Het is wel vindbaar. \nMVG\neggie
#> 92 Dag Hahaxghu,\n\nWelkom bij OSM.\n\nHoe kan nu een officieel adres veranderen?\n\nIk draai je aanpassing terug.\nAnders krijg je twee identieke adressen en een missende. \n\nMVG\neggie
#> 93 Welkom bij OpenStreetMap. Ik heb een uitgebreid welkomstbericht met wat handige tips en links gestuurd als privebericht.\nMVG,\nEggie\nNamens de OSM Community\n\n\n\n
#> 94 Welkom bij OpenStreetMap. Ik heb een uitgebreid welkomstbericht met wat handige tips en links gestuurd als privebericht.\nMVG,\nEggie\nNamens de OSM Community\n\n\n\n
#> 95 PS - https://community.openstreetmap.org/t/recap-osm-route-master-structuring-for-taoyuan-airport-mrt-and-the-broader-question-of-modeling-through-running-services/147688
#> 96 Well, Yes and No. They do run on the same lines and tracks, but I wouldn't quite call them variants at this pt of time. They are more loosely Bakerloo and Lioness look-alike.
#> 97 Bonjour,\n\nJ'ai constaté que vous aviez redéplacé tous les points adresses de Saint-Frion à l'intérieur des batiments. Cela ne correspond pas au consensus en France qui est :\n"Placer préférentiellement le nœud adresse à l'interface entre la voie et le terrain ou le bâtiment en question, près d'une entrée (qu'elle donne sur un jardin ou directement sur un bâtiment)"\n\nVoir par exemple le wiki :\nhttps://wiki.openstreetmap.org/wiki/FR:Le_Sch%C3%A9ma_de_Charlieu_:_une_proposition_autour_des_adresses#Comment_tracer_et_placer_l'adresse\n\nBien cordialement.
#> 98 Would also like to add that this likely should have been three to four separate changesets. Completely changing three junctions and adding an operator wikidata to a power line in a single changeset is not a good idea and makes it very hard to review your changes. It also made it a bit of a hassle to revert the changeset, my thanks to https://www.openstreetmap.org/user/LordGarySugar for reverting for me.\n\nThank you for your time contributing to the map, apologies it needed reverting in this case. Also thank you for requesting a review on this change, was very helpful in bringing it to my attention. Look forward to what you're going to add in future!
#> 99 Hi,\n\ncould you tell me where did you get the "house=cluster" tag from?\n\nThere's no such thing in the wiki:\nhttps://wiki.openstreetmap.org/wiki/Tag:building%3Dhouse
#> 100 Partially reverted in https://www.openstreetmap.org/changeset/189066261
# Search for changeset comments by a specific user:
osm_search_comment_changeset_discussion(user = "Steve", format = "json")
#> $version
#> [1] "0.6"
#>
#> $generator
#> [1] "OpenStreetMap server"
#>
#> $copyright
#> [1] "OpenStreetMap and contributors"
#>
#> $attribution
#> [1] "http://www.openstreetmap.org/copyright"
#>
#> $license
#> [1] "http://opendatacommons.org/licenses/odbl/1-0/"
#>
#> $comments
#> $comments[[1]]
#> $comments[[1]]$id
#> [1] 664366
#>
#> $comments[[1]]$visible
#> [1] TRUE
#>
#> $comments[[1]]$date
#> [1] "2021-02-25T19:31:46Z"
#>
#> $comments[[1]]$uid
#> [1] 1
#>
#> $comments[[1]]$user
#> [1] "Steve"
#>
#> $comments[[1]]$text
#> [1] "woo!"
#>
#>
#>
# Search for changeset comments between January 1st and January 2nd, 2015:
osm_search_comment_changeset_discussion(from = "2015-01-01", to = "2015-01-02", format = "xml")
#> {xml_document}
#> <osm version="0.6" generator="OpenStreetMap server" copyright="OpenStreetMap and contributors" attribution="http://www.openstreetmap.org/copyright" license="http://opendatacommons.org/licenses/odbl/1-0/">
#> [1] <comment id="3597" date="2015-01-01T23:41:30Z" visible="true" uid="10915 ...
#> [2] <comment id="3596" date="2015-01-01T23:36:36Z" visible="true" uid="88164 ...
#> [3] <comment id="3595" date="2015-01-01T23:29:40Z" visible="true" uid="88164 ...
#> [4] <comment id="3594" date="2015-01-01T23:24:27Z" visible="true" uid="61942 ...
#> [5] <comment id="3593" date="2015-01-01T23:19:58Z" visible="true" uid="88164 ...
#> [6] <comment id="3592" date="2015-01-01T23:15:54Z" visible="true" uid="23858 ...
#> [7] <comment id="3591" date="2015-01-01T23:15:38Z" visible="true" uid="39688 ...
#> [8] <comment id="3590" date="2015-01-01T23:12:25Z" visible="true" uid="61942 ...
#> [9] <comment id="3589" date="2015-01-01T22:23:35Z" visible="true" uid="61942 ...
#> [10] <comment id="3588" date="2015-01-01T22:14:08Z" visible="true" uid="61942 ...
#> [11] <comment id="3587" date="2015-01-01T21:53:43Z" visible="true" uid="18850 ...
#> [12] <comment id="3586" date="2015-01-01T21:53:40Z" visible="true" uid="61942 ...
#> [13] <comment id="3585" date="2015-01-01T21:29:38Z" visible="true" uid="33121 ...
#> [14] <comment id="3584" date="2015-01-01T20:30:27Z" visible="true" uid="25485 ...
#> [15] <comment id="3583" date="2015-01-01T19:49:08Z" visible="true" uid="23858 ...
#> [16] <comment id="3582" date="2015-01-01T19:40:03Z" visible="true" uid="12992 ...
#> [17] <comment id="3581" date="2015-01-01T19:39:16Z" visible="true" uid="12992 ...
#> [18] <comment id="3580" date="2015-01-01T17:53:47Z" visible="true" uid="13112 ...
#> [19] <comment id="3579" date="2015-01-01T16:35:02Z" visible="true" uid="10915 ...
#> [20] <comment id="3578" date="2015-01-01T16:23:43Z" visible="true" uid="61942 ...
#> ...