Skip to contents

Returns the existing notes in the specified bounding box. The notes will be ordered by the date of their last change, the most recent one will be first.

Usage

osm_read_bbox_notes(
  bbox,
  limit = 100,
  closed = 7,
  format = c("R", "sf", "xml", "rss", "json", "gpx")
)

Arguments

bbox

Coordinates for the area to retrieve the notes from (left,bottom,right,top). Floating point numbers in degrees, expressing a valid bounding box, not larger than the configured size limit, 25 square degrees, not overlapping the dateline. It can be specified by a character, matrix, vector, bbox object from sf, a SpatExtent from terra. Unnamed vectors and matrices will be sorted appropriately and must merely be in the order (x, y, x, y) or x in the first column and y in the second column.

limit

Specifies the number of entries returned at max. A value between 1 and 10000 is valid. Default to 100.

closed

Specifies the number of days a note needs to be closed to no longer be returned. A value of 0 means only open notes are returned. A value of -1 means all notes are returned. Default to 7.

format

Format of the output. Can be "R" (default), "sf" "xml", "rss", "json" or "gpx".

Value

If format = "R", returns a data frame with one map note per row. If format = "sf", returns a sf object from sf.

format = "xml"

Returns a xml2::xml_document with the following format:

<?xml version="1.0" encoding="UTF-8"?>
<osm version="0.6" generator="OpenStreetMap server" copyright="OpenStreetMap and contributors" attribution="https://www.openstreetmap.org/copyright" license="https://opendatacommons.org/licenses/odbl/1-0/">
  <note lon="0.1000000" lat="51.0000000">
    <id>16659</id>
    <url>https://master.apis.dev.openstreetmap.org/api/0.6/notes/16659</url>
    <comment_url>https://master.apis.dev.openstreetmap.org/api/0.6/notes/16659/comment</comment_url>
    <close_url>https://master.apis.dev.openstreetmap.org/api/0.6/notes/16659/close</close_url>
    <date_created>2019-06-15 08:26:04 UTC</date_created>
    <status>open</status>
    <comments>
      <comment>
        <date>2019-06-15 08:26:04 UTC</date>
        <uid>1234</uid>
        <user>userName</user>
        <user_url>https://master.apis.dev.openstreetmap.org/user/userName</user_url>
        <action>opened</action>
        <text>ThisIsANote</text>
        <html>&lt;p&gt;ThisIsANote&lt;/p&gt;</html>
      </comment>
      ...
    </comments>
  </note>
  ...
</osm>

format = "json"

Returns a list with the following json structure:

{
  "type": "FeatureCollection",
  "features": [
    {
      "type": "Feature",
      "geometry": {"type": "Point", "coordinates": [0.1000000, 51.0000000]},
      "properties": {
        "id": 16659,
        "url": "https://master.apis.dev.openstreetmap.org/api/0.6/notes/16659.json",
        "comment_url": "https://master.apis.dev.openstreetmap.org/api/0.6/notes/16659/comment.json",
        "close_url": "https://master.apis.dev.openstreetmap.org/api/0.6/notes/16659/close.json",
        "date_created": "2019-06-15 08:26:04 UTC",
        "status": "open",
        "comments": [
          {"date": "2019-06-15 08:26:04 UTC", "uid": 1234, "user": "userName", "user_url": "https://master.apis.dev.openstreetmap.org/user/userName", "action": "opened", "text": "ThisIsANote", "html": "<p>ThisIsANote</p>"},
          ...
        ]
      }
    }
  ]
}

format = "rss" & format = "gpx"

For format in "rss", and "gpx", a xml2::xml_document with the corresponding format.

Note

The comment properties (uid, user, user_url) will be omitted if the comment was anonymous.

See also

Examples

notes <- osm_read_bbox_notes(bbox = c(3.7854767, 39.7837403, 4.3347931, 40.1011851), limit = 10)
## bbox as a character value also works (bbox = "3.7854767,39.7837403,4.3347931,40.1011851").
notes
#>          lon        lat      id
#> 1  3.9704368 39.9337510 5301779
#> 2  3.8509655 39.9998077 5275356
#> 3  3.8362791 39.9991039 5273525
#> 4  4.0097062 39.9336562 5273519
#> 5  4.2835090 39.8902310 5272733
#> 6  4.0419960 39.9156793 5272672
#> 7  4.0097223 39.9336709 5272413
#> 8  3.9653895 39.9389582 5271470
#> 9  3.9636228 39.9386971 5271480
#> 10 3.9641064 39.9389008 5271479
#>                                                        url
#> 1  https://api.openstreetmap.org/api/0.6/notes/5301779.xml
#> 2  https://api.openstreetmap.org/api/0.6/notes/5275356.xml
#> 3  https://api.openstreetmap.org/api/0.6/notes/5273525.xml
#> 4  https://api.openstreetmap.org/api/0.6/notes/5273519.xml
#> 5  https://api.openstreetmap.org/api/0.6/notes/5272733.xml
#> 6  https://api.openstreetmap.org/api/0.6/notes/5272672.xml
#> 7  https://api.openstreetmap.org/api/0.6/notes/5272413.xml
#> 8  https://api.openstreetmap.org/api/0.6/notes/5271470.xml
#> 9  https://api.openstreetmap.org/api/0.6/notes/5271480.xml
#> 10 https://api.openstreetmap.org/api/0.6/notes/5271479.xml
#>                                                        comment_url
#> 1  https://api.openstreetmap.org/api/0.6/notes/5301779/comment.xml
#> 2  https://api.openstreetmap.org/api/0.6/notes/5275356/comment.xml
#> 3  https://api.openstreetmap.org/api/0.6/notes/5273525/comment.xml
#> 4  https://api.openstreetmap.org/api/0.6/notes/5273519/comment.xml
#> 5  https://api.openstreetmap.org/api/0.6/notes/5272733/comment.xml
#> 6  https://api.openstreetmap.org/api/0.6/notes/5272672/comment.xml
#> 7  https://api.openstreetmap.org/api/0.6/notes/5272413/comment.xml
#> 8  https://api.openstreetmap.org/api/0.6/notes/5271470/comment.xml
#> 9  https://api.openstreetmap.org/api/0.6/notes/5271480/comment.xml
#> 10 https://api.openstreetmap.org/api/0.6/notes/5271479/comment.xml
#>                                                        close_url
#> 1  https://api.openstreetmap.org/api/0.6/notes/5301779/close.xml
#> 2  https://api.openstreetmap.org/api/0.6/notes/5275356/close.xml
#> 3  https://api.openstreetmap.org/api/0.6/notes/5273525/close.xml
#> 4  https://api.openstreetmap.org/api/0.6/notes/5273519/close.xml
#> 5  https://api.openstreetmap.org/api/0.6/notes/5272733/close.xml
#> 6  https://api.openstreetmap.org/api/0.6/notes/5272672/close.xml
#> 7  https://api.openstreetmap.org/api/0.6/notes/5272413/close.xml
#> 8  https://api.openstreetmap.org/api/0.6/notes/5271470/close.xml
#> 9  https://api.openstreetmap.org/api/0.6/notes/5271480/close.xml
#> 10 https://api.openstreetmap.org/api/0.6/notes/5271479/close.xml
#>           date_created status                                    comments
#> 1  2026-05-20 14:59:05   open        1 comment from 2026-05-20 by D_FENCE
#> 2  2026-05-02 13:11:38   open      1 comment from 2026-05-02 by punky2002
#> 3  2026-05-01 11:08:23   open       1 comment from 2026-05-01 by donux-nl
#> 4  2026-05-01 11:06:07   open       1 comment from 2026-05-01 by donux-nl
#> 5  2026-04-30 16:48:29   open 1 comment from 2026-04-30 by anonymous user
#> 6  2026-04-30 15:50:39   open       1 comment from 2026-04-30 by donux-nl
#> 7  2026-04-30 12:32:56   open       1 comment from 2026-04-30 by donux-nl
#> 8  2026-04-29 16:35:41   open      2 comments from 2026-04-29 by donux-nl
#> 9  2026-04-29 16:41:51   open       1 comment from 2026-04-29 by donux-nl
#> 10 2026-04-29 16:40:47   open       1 comment from 2026-04-29 by donux-nl