Search changeset comments
Source:R/osmapi_changeset_discussion.R
osm_search_comment_changeset_discussion.RdReturns changeset comments that match the specified query. If no query is provided, the most recent changeset comments are returned.
Usage
osm_search_comment_changeset_discussion(
user,
from,
to,
format = c("R", "xml", "json"),
tags_in_columns = FALSE
)Arguments
- user
Search for changeset comments created by the user with the given user id (numeric) or display name (character).
- from
Beginning date range. See details for the valid formats.
- to
End date range. Only works when
fromis supplied. See details for the valid formats.- format
Format of the output. Can be
"R"(default),"xml", or"json".If
FALSE(default), the tags of the changesets are saved in a single list columntagscontaining adata.framefor each changeset with the keys and values. IfTRUE, add a column for each key. Ignored ifformat != "R".
Value
If format = "R", returns a data frame with one comment per If format = "xml", returns a
xml2::xml_document. If format = "json", returns a list with the json structure.
Details
The valid formats for from and to parameters are POSIXt values or characters preferably in
ISO 8601 format.
See also
Other changeset discussion's functions:
osm_comment_changeset_discussion(),
osm_hide_comment_changeset_discussion(),
osm_subscribe_changeset_discussion()
Examples
# See the latest changeset comments globally:
osm_search_comment_changeset_discussion()
#> id date visible uid user
#> 1 1636608 2026-07-31 05:35:54 TRUE 322785 BCNorwich
#> 2 1636607 2026-07-31 05:30:05 TRUE 20144444 MappingMore
#> 3 1636606 2026-07-31 05:29:08 TRUE 2742073 arjunaraoc
#> 4 1636605 2026-07-31 05:28:16 TRUE 461130 Fizzie-DWG
#> 5 1636604 2026-07-31 05:27:37 TRUE 2742073 arjunaraoc
#> 6 1636603 2026-07-31 05:23:55 TRUE 22419583 Gitasaleh Virast
#> 7 1636602 2026-07-31 05:19:39 TRUE 461130 Fizzie-DWG
#> 8 1636601 2026-07-31 05:15:47 TRUE 461130 Fizzie-DWG
#> 9 1636600 2026-07-31 05:13:10 TRUE 18511019 Senihtu
#> 10 1636599 2026-07-31 05:12:29 TRUE 461130 Fizzie-DWG
#> 11 1636598 2026-07-31 05:09:36 TRUE 21982638 pwbriggs
#> 12 1636597 2026-07-31 05:05:46 TRUE 21982638 pwbriggs
#> 13 1636596 2026-07-31 05:03:36 TRUE 242345 confusedbuffalo
#> 14 1636595 2026-07-31 04:58:13 TRUE 3302935 Nic Reich
#> 15 1636594 2026-07-31 04:56:46 TRUE 21982638 pwbriggs
#> 16 1636593 2026-07-31 04:55:46 TRUE 3302935 Nic Reich
#> 17 1636592 2026-07-31 04:47:47 TRUE 3302935 Nic Reich
#> 18 1636591 2026-07-31 04:45:17 TRUE 22945192 Vladislav Grechannik
#> 19 1636590 2026-07-31 04:41:25 TRUE 20035847 cgreggescalante
#> 20 1636589 2026-07-31 04:37:52 TRUE 23896451 CAM-Gerlach_Repair
#> 21 1636588 2026-07-31 04:29:27 TRUE 3302935 Nic Reich
#> 22 1636587 2026-07-31 04:29:12 TRUE 23896451 CAM-Gerlach_Repair
#> 23 1636586 2026-07-31 04:28:24 TRUE 23896451 CAM-Gerlach_Repair
#> 24 1636585 2026-07-31 04:21:54 TRUE 401472 ftrebien
#> 25 1636584 2026-07-31 04:11:20 TRUE 20614726 ooosssay
#> 26 1636583 2026-07-31 04:10:55 TRUE 21664861 LambdaComplex
#> 27 1636582 2026-07-31 04:10:45 TRUE 92286 Baloo Uriza
#> 28 1636581 2026-07-31 04:07:20 TRUE 16979815 citrula
#> 29 1636580 2026-07-31 03:55:19 TRUE 20159984 Alliegaytor
#> 30 1636579 2026-07-31 03:54:10 TRUE 20159984 Alliegaytor
#> 31 1636578 2026-07-31 03:52:41 TRUE 20159984 Alliegaytor
#> 32 1636577 2026-07-31 03:45:08 TRUE 16979815 citrula
#> 33 1636576 2026-07-31 03:41:11 TRUE 1293194 nevw
#> 34 1636575 2026-07-31 03:24:22 TRUE 22232921 Corbeno
#> 35 1636574 2026-07-31 03:16:25 TRUE 22945192 Vladislav Grechannik
#> 36 1636573 2026-07-31 03:09:00 TRUE 6810910 nerihv
#> 37 1636572 2026-07-31 03:07:37 TRUE 1842197 O Fim
#> 38 1636571 2026-07-31 03:06:07 TRUE 1842197 O Fim
#> 39 1636570 2026-07-31 03:02:15 TRUE 21491961 schobbish
#> 40 1636569 2026-07-31 03:00:56 TRUE 6810910 nerihv
#> 41 1636568 2026-07-31 02:57:45 TRUE 755114 muralito
#> 42 1636567 2026-07-31 02:57:38 TRUE 1842197 O Fim
#> 43 1636566 2026-07-31 02:55:29 TRUE 6810910 nerihv
#> 44 1636565 2026-07-31 02:53:09 TRUE 401472 ftrebien
#> 45 1636564 2026-07-31 02:51:23 TRUE 1842197 O Fim
#> 46 1636563 2026-07-31 02:49:46 TRUE 6810910 nerihv
#> 47 1636562 2026-07-31 02:45:23 TRUE 1842197 O Fim
#> 48 1636561 2026-07-31 02:41:24 TRUE 92286 Baloo Uriza
#> 49 1636560 2026-07-31 02:40:09 TRUE 6810910 nerihv
#> 50 1636559 2026-07-31 02:38:47 TRUE 23999820 alpacaMaps
#> 51 1636558 2026-07-31 02:38:46 TRUE 23999820 alpacaMaps
#> 52 1636557 2026-07-31 02:38:46 TRUE 23999820 alpacaMaps
#> 53 1636556 2026-07-31 02:35:31 TRUE 22091888 NyngYun
#> 54 1636555 2026-07-31 02:33:01 TRUE 1842197 O Fim
#> 55 1636554 2026-07-31 02:32:27 TRUE 23999820 alpacaMaps
#> 56 1636553 2026-07-31 02:32:26 TRUE 23999820 alpacaMaps
#> 57 1636552 2026-07-31 02:32:25 TRUE 23999820 alpacaMaps
#> 58 1636551 2026-07-31 02:32:25 TRUE 23999820 alpacaMaps
#> 59 1636550 2026-07-31 02:32:24 TRUE 23999820 alpacaMaps
#> 60 1636549 2026-07-31 02:32:24 TRUE 23999820 alpacaMaps
#> 61 1636548 2026-07-31 02:32:23 TRUE 23999820 alpacaMaps
#> 62 1636547 2026-07-31 02:32:23 TRUE 23999820 alpacaMaps
#> 63 1636546 2026-07-31 02:32:22 TRUE 23999820 alpacaMaps
#> 64 1636545 2026-07-31 02:32:21 TRUE 23999820 alpacaMaps
#> 65 1636544 2026-07-31 02:32:21 TRUE 23999820 alpacaMaps
#> 66 1636543 2026-07-31 02:32:21 TRUE 23999820 alpacaMaps
#> 67 1636542 2026-07-31 02:32:20 TRUE 23999820 alpacaMaps
#> 68 1636541 2026-07-31 02:32:19 TRUE 23999820 alpacaMaps
#> 69 1636540 2026-07-31 02:32:19 TRUE 23999820 alpacaMaps
#> 70 1636539 2026-07-31 02:32:18 TRUE 23999820 alpacaMaps
#> 71 1636538 2026-07-31 02:32:18 TRUE 23999820 alpacaMaps
#> 72 1636537 2026-07-31 02:32:17 TRUE 23999820 alpacaMaps
#> 73 1636536 2026-07-31 02:32:17 TRUE 23999820 alpacaMaps
#> 74 1636535 2026-07-31 02:32:17 TRUE 23999820 alpacaMaps
#> 75 1636534 2026-07-31 02:32:16 TRUE 23999820 alpacaMaps
#> 76 1636533 2026-07-31 02:32:15 TRUE 23999820 alpacaMaps
#> 77 1636532 2026-07-31 02:32:15 TRUE 23999820 alpacaMaps
#> 78 1636531 2026-07-31 02:32:15 TRUE 23999820 alpacaMaps
#> 79 1636530 2026-07-31 02:32:14 TRUE 23999820 alpacaMaps
#> 80 1636529 2026-07-31 02:32:13 TRUE 23999820 alpacaMaps
#> 81 1636528 2026-07-31 02:32:12 TRUE 23999820 alpacaMaps
#> 82 1636527 2026-07-31 02:32:12 TRUE 23999820 alpacaMaps
#> 83 1636526 2026-07-31 02:32:11 TRUE 23999820 alpacaMaps
#> 84 1636525 2026-07-31 02:32:11 TRUE 23999820 alpacaMaps
#> 85 1636524 2026-07-31 02:32:10 TRUE 23999820 alpacaMaps
#> 86 1636523 2026-07-31 02:32:10 TRUE 23999820 alpacaMaps
#> 87 1636522 2026-07-31 02:32:09 TRUE 23999820 alpacaMaps
#> 88 1636521 2026-07-31 02:32:09 TRUE 23999820 alpacaMaps
#> 89 1636520 2026-07-31 02:32:08 TRUE 23999820 alpacaMaps
#> 90 1636519 2026-07-31 02:32:07 TRUE 23999820 alpacaMaps
#> 91 1636518 2026-07-31 02:32:07 TRUE 23999820 alpacaMaps
#> 92 1636517 2026-07-31 02:32:06 TRUE 23999820 alpacaMaps
#> 93 1636516 2026-07-31 02:32:06 TRUE 23999820 alpacaMaps
#> 94 1636515 2026-07-31 02:32:05 TRUE 23999820 alpacaMaps
#> 95 1636514 2026-07-31 02:32:05 TRUE 23999820 alpacaMaps
#> 96 1636513 2026-07-31 02:32:04 TRUE 23999820 alpacaMaps
#> 97 1636512 2026-07-31 02:32:04 TRUE 23999820 alpacaMaps
#> 98 1636511 2026-07-31 02:32:03 TRUE 23999820 alpacaMaps
#> 99 1636510 2026-07-31 02:32:03 TRUE 23999820 alpacaMaps
#> 100 1636509 2026-07-31 02:32:02 TRUE 23999820 alpacaMaps
#> comment_text
#> 1 Changeset reverted because it only added a duplicated highway, which could have caused disruption to routing.
#> 2 Partially reverted in https://www.openstreetmap.org/changeset/186685825
#> 3 OSMCha software requires that I review everything as either good or bad. There is no in between. When I mark it as bad, it may only be that it doesn't fit the OSM tagging scheme. \n\nAdditional comments for resolving the issue: \nPlease update the tags as per https://wiki.openstreetmap.org/wiki/Key:building\n\nIf you can't resolve, please respond to the discussion on changset, so that another contributor can help fix it.\n ---\n #REVIEWED_BAD #OSMCHA\n Published using OSMCha: https://osmcha.org/changesets/186511729\n
#> 4 Please see https://www.openstreetmap.org/user_blocks/21037
#> 5 The OSMCha software requires that I review everything as either good or bad. There is no in between. When I mark it as bad, it may only be that it doesn't fit the OSM tagging scheme. \n\nAdditional comments for resolving the issue: \nname can not be generic. Please update tags as per https://wiki.openstreetmap.org/wiki/Tag:building%3Dhotel\nIf you can't resolve, please respond to the discussion on changset, so that another contributor can help fix it.\n ---\n #REVIEWED_BAD #OSMCHA\n Published using OSMCha: https://osmcha.org/changesets/186511158\n
#> 6 قسمت تونل خط یک (شوش-تجریش) نباید دوریل باشد و باید یک ریل باشد.
#> 7 Please see https://www.openstreetmap.org/user_blocks/21036
#> 8 Please see https://www.openstreetmap.org/user_blocks/21035
#> 9 Hi!\nDurch Dornbachstraße und Lahnstraße laufen einige Buslinien.\nLegst Du die noch um?\nGruß Senihtu
#> 10 Please see https://www.openstreetmap.org/user_blocks/21034
#> 11 Hello!\n\nI think that this changeset uses the website=* tag incorrectly. From the English wiki:\n\n>Choose specific URLs over homepages. For example, use website=https://www.islandbuses.info/services/SVCT/8 instead of website=https://www.islandbuses.info. Consider brand:website=*, network:website=*, or operator:website=* if you want to store a URL for those.\n\nMy understanding is that a website=* tag should be the webpage of the particular branch or location of each building.
#> 12 Do all these branches really have the same opening_hours nationwide?
#> 13 Thank you, in general I avoided So>Su for that reason, and I believe this was the only such change that I made. Based on the context of Mo-Sa being defined here and "So" having some different value, I felt that it was almost certain that it should be Sunday.
#> 14 Thanks for fixing my error!\n ---\n \n Published using OSMCha: https://osmcha.org/changesets/186594042\n
#> 15 Hey confusedbuffalo! Thanks for the tool.\n\nI think that you were incorrect on https://www.openstreetmap.org/node/11253618657/history/4 and probably many others. I am not from anywhere near Poland nor do I know or speak Polish, but I believe that So stands for Sobota -- Saturday. https://en.wiktionary.org/wiki/sobota#Polish // https://en.wikipedia.org/wiki/Names_of_the_days_of_the_week#:~:text=Polish\n\nLet me know what you think.
#> 16 Hello! Thanks for contributing to OpenStreetMap. Your edit did not go through correctly. All of the tags were inside of the "man_made" tag. I've corrected it now.\n ---\n \n Published using OSMCha: https://osmcha.org/changesets/186598968\n
#> 17 Hello. I'm sorry you may be dealing with trespassers.\n\nOpenStreetMap is a source of truth for what exists in the world, so we don't delete paths even on private property. Therefore your edit was reverted. Please see here for details: https://wiki.openstreetmap.org/wiki/Why_we_won%27t_delete_roads_on_private_property\n\nAll the paths in this area are now properly marked as private, so that should inform people (and routing software) to stay away.\n ---\n #REVIEWED_BAD #OSMCHA\n Published using OSMCha: https://osmcha.org/changesets/186672315\n
#> 18 uhh, in an ideal world we'd have the whole D1 route mapped, right? It certantly is somewhere there (even if poorly signed) and we have some reason to assume that it duplicates EV9's path (see https://pisrs.si/api/datoteke/integracije/351444707 where gov explicitly calls D1 as EV9). I think it's beneficial to future mappers to save the current D1 section for future correction when it gets more signage and it better reflects the real world sitation that the segment exists somewhere between Mostečno and Zg. Poljčane
#> 19 Thanks for the contributions! I noticed you mentioned using street level imagery in your source and description. Just wanted to make sure that this wasn't using Google Street View or Apple Look Around, as those have licenses that are incompatible with OpenStreetMap. Thanks!
#> 20 As discussed in changeset 186349772 , it is usually okay to merge (or delete) address nodes that are already tagged exactly as such on buildings and/or POI nodes, but not if they aren't already tagged on something else as was the case in most cases here.\n\nhttps://osm.org/changeset/186349772\n\nTherefore, I restored or merged the addresses that did not already exist in changeset 186684589\n\nhttps://osm.org/changeset/186684589
#> 21 FYI this changeset incorrectly marks some paths as crossings. I've fixed it now.
#> 22 Restored or merged the relevant addresses and POI nodes/tags that don't already exist, and cleaned up some other tags in changeset 186684142\n\nhttps://osm.org/changeset/186684142
#> 23 If the POI ("place") node already contains the address tags, then it is okay to remove, or you can merge the nodes if both exist and you know the address of the POI. If only the address nodes exist and you want to add the POI, don't delete the existing address nodes, just add the POI tags to the address nodes. And certainly don't delete the address node if the address is not already used for at least one POI node, or you are losing valid information.\n\nIn many cases in this changeset, the address already existed on a POI node, but in others no POI existed for that address. Furthermore, you deleted the entire building most of the addresses were contained with that had many very detailed tags, and you also deleted a number of POI nodes with very detailed tags in favor of those you added you very few, which is also a lost of information.\n\nIn general, especially as a beginner, you shouldn't delete anything unless you not only think but 100% know, based on clear guidance in the wiki and from other mappers, that the object either completely doesn't exist at all in the real world or that the tags are wrong/redundant.\n\nAt some amount of effort, I manually went through the deleted objects one by one and restored or merged those that did not already exist, as well as fixing up some tags, in changeset 186684142\n\nhttps://osm.org/changeset/186684142
#> 24 Esclarecendo: o comentário no changeset talvez tenha sido pouco claro, mas a etiqueta surface=* não foi removida: eu substituí surface=concrete por surface=paved. Essa alteração não melhora nem piora o roteamento nos casos discutidos: a maioria das aplicações trata os dois valores igualmente. A diferença é que mapeadores em campo, por exemplo usando o StreetComplete, passarão a ser perguntados sobre o tipo de superfície que essas calçadas têm. O valor surface=paved pode ser usado mesmo ao mapear remotamente, com base nas imagens aéreas. Já valores específicos como surface=concrete e surface=paving_stones exigem visita no local porque as imagens não têm tanta nitidez.
#> 25 very
#> 26 access=no?
#> 27 Oh, well, seems we both learned something new today. Neat!
#> 28 Since this bay is (perhaps incorrectly?) mapped inside the coastline, I think this stopped the water area from rendering
#> 29 reverted: changeset/186683509
#> 30 reverted: changeset/186683480
#> 31 reverted: changeset/186683431\n\nplease stop adding bogus tourism=theme_park to osm
#> 32 please don't add nonexistent road segments, even with access=no\n\nalso, can you explain what adding the `ref=CR 180` to the sidewalk is intended to convey?
#> 33 Hi, I adjusted your business tags.\nIs the business office located at unit 202, 100 New South Head Road.\nThe website listed has GF Asset Management office at 80 Perry Street, Matraville, NSW, 2036\n+61 8302 9500\nI assume this is the head office and you are adding another of their offices.\n\nI deleted addr:state, postcode,suburb as these are not required in AU
#> 34 I've never seen that standard before. This site (which I used) seems to accept "closed" https://opening-hours.pages.dev/
#> 35 See panoramax for a photo I made last time I was there https://api.panoramax.xyz/en/index?s=fp;s2;p4506710e-4c9a-45fe-be2c-099f0ea2a363;c-71.00/0.00/30;m17/46.373156/15.641708;vg;udefault
#> 36 mapeado con bing desplazamiento usado 3.4, 0.24
#> 37 Para mim encerrado vou reclamar no local correto.
#> 38 Tudo começou por que o FT insinuou que eu era mentiroso com desrespeito e prepotente . Seu comportamento inadequado, mentiroso e desrespeitoso revela muito sobre sua falta de Idoneidade.
#> 39 nice
#> 40 mapeado con bing desplazamiento usado 3.4, 0.24
#> 41 Hola. El nombre no estaba incompleto, de hecho estaba bien como estaba, porque el tipo de negocio "ferreteria" se describe correctamente con shop=hardware
#> 42 enfim eu posso ter me equivocado em ter usado por engano o piso asfato em alguma edição um simples erro que não justifica uma edição em larga escala sem nenhuma verificação , a FT use videos e imagens atuais coisas de anos atrás já mudaram inclusive a av paulista mudou faz pouco tempo
#> 43 mapeado con bing desplazamiento usado 3.4, 0.24
#> 44 Esclarecendo: no grupo OSM São Paulo, o aviso foi postado publicamente apresentando o problema e perguntando por objeções. Ele permaneceu sem objeção por 3 dias, com leitura confirmada por pelo menos 8 membros ativos da comunidade nacional. Hoje, passados 6 dias, foram lidas por 13 membros e ainda não houve nenhuma objeção.
#> 45 FT disse (o percurso segue pela avenida Ipiranga entre a avenida São João e a avenida São Luís, e nele, surface=concrete cobre menos de 50% do percurso em 6 das 7 faces) e mapear por fotos antigas do google da nisso, as vias citadas estão sendo totalmente remodeladas com puro concreto pude ver isso hoje quando fui na santa ifigenia , parece ser um novo padrão da PMSP outro detalhe diz que calçadas de concreto são na realidade placas pois as mesmas tem uma junta de dilatação , com certeza vai dizer que não disse isso pois editou as mensagens.
#> 46 mapeado con bing desplazamiento usado 3.4, 0.24
#> 47 O FT disse (é que a execução incompleta da migração para o mapeamento como linha separada gera erros de roteamento pedestre) , fake no própria discussão no grupo qualidade fiz um video provando que o roteamento funcionava perfeitamente , e o começo do debate por parte dele era que a calçada sem a etiqueta sidewalk:separete não funcionava eu sugeri que o mesmo a editar mas isso ele não faz por causa do trabalho envolvido, agora que o mesmo removeu as etiquetas vai dizer que o roteamento so funciona por que ele consertou kkkkkkkk.
#> 48 "closed" on a lot of these hours should probably be "off" instead, right?\n ---\n \n Published using OSMCha: https://osmcha.org/changesets/186589452\n
#> 49 mapeado con bing desplazamiento usado 3.4, 0.24
#> 50 This changeset adds one or more surveillance cameras in a spot that looks unlikely — the nodes sit well away from any road, which usually means the cameras aren't physically present on the ground.\n\nIf these cameras are real, please let us know so the map stays accurate. Otherwise, we'd kindly ask that you avoid adding cameras that aren't actually there, and that you remove any temporary or test nodes once you're done.\n\nIf this was simply a mistake, no problem at all — just clean up the nodes that don't correspond to a real-world camera, and leave a quick note here so we can help.\n\nThanks for helping keep OpenStreetMap accurate.\n\n— alpacaMaps
#> 51 This changeset adds one or more surveillance cameras in a spot that looks unlikely — the nodes sit well away from any road, which usually means the cameras aren't physically present on the ground.\n\nIf these cameras are real, please let us know so the map stays accurate. Otherwise, we'd kindly ask that you avoid adding cameras that aren't actually there, and that you remove any temporary or test nodes once you're done.\n\nIf this was simply a mistake, no problem at all — just clean up the nodes that don't correspond to a real-world camera, and leave a quick note here so we can help.\n\nThanks for helping keep OpenStreetMap accurate.\n\n— alpacaMaps
#> 52 This changeset adds one or more surveillance cameras in a spot that looks unlikely — the nodes sit well away from any road, which usually means the cameras aren't physically present on the ground.\n\nIf these cameras are real, please let us know so the map stays accurate. Otherwise, we'd kindly ask that you avoid adding cameras that aren't actually there, and that you remove any temporary or test nodes once you're done.\n\nIf this was simply a mistake, no problem at all — just clean up the nodes that don't correspond to a real-world camera, and leave a quick note here so we can help.\n\nThanks for helping keep OpenStreetMap accurate.\n\n— alpacaMaps
#> 53 确实是这样 所以我认为应当暂且按校门标记为规范
#> 54 FT disse (A discussão se iniciou no grupo Qualidade de Mapeamento, e a sondagem e aval referente à reversão das edições ocorreu no grupo OSM São Paulo) Nossa mentir faz parte da vida do FT ninguém deu aval para ele , apenas o usuário bonix o perguntou se o FT tinha entrado em contato comigo para discutir o assunto, esse foi todo aval que ele disse ter recebido para fazer suas reedições as cais não tenho nada contra na etiqueta kerb,e barrier quanto a etiqueta concrete deveria ter revisado ja que usa o street view para tomar suas decisões deveria ter revisado rua por rua , eu mesmo poderia ter dado um reverte nele.
#> 55 Reverting clear vandalism
#> 56 Reverting clear vandalism
#> 57 Reverting clear vandalism
#> 58 Reverting clear vandalism
#> 59 Reverting clear vandalism
#> 60 Reverting clear vandalism
#> 61 Reverting clear vandalism
#> 62 Reverting clear vandalism
#> 63 Reverting clear vandalism
#> 64 Reverting clear vandalism
#> 65 Reverting clear vandalism
#> 66 Reverting clear vandalism
#> 67 Reverting clear vandalism
#> 68 Reverting clear vandalism
#> 69 Reverting clear vandalism
#> 70 Reverting clear vandalism
#> 71 Reverting clear vandalism
#> 72 Reverting clear vandalism
#> 73 Reverting clear vandalism
#> 74 Reverting clear vandalism
#> 75 Reverting clear vandalism
#> 76 Reverting clear vandalism
#> 77 Reverting clear vandalism
#> 78 Reverting clear vandalism
#> 79 Reverting clear vandalism
#> 80 Reverting clear vandalism
#> 81 Reverting clear vandalism
#> 82 Reverting clear vandalism
#> 83 Reverting clear vandalism
#> 84 Reverting clear vandalism
#> 85 Reverting clear vandalism
#> 86 Reverting clear vandalism
#> 87 Reverting clear vandalism
#> 88 Reverting clear vandalism
#> 89 Reverting clear vandalism
#> 90 Reverting clear vandalism
#> 91 Reverting clear vandalism
#> 92 Reverting clear vandalism
#> 93 Reverting clear vandalism
#> 94 Reverting clear vandalism
#> 95 Reverting clear vandalism
#> 96 Reverting clear vandalism
#> 97 Reverting clear vandalism
#> 98 Reverting clear vandalism
#> 99 Reverting clear vandalism
#> 100 Reverting clear vandalism
# Search for changeset comments by a specific user:
osm_search_comment_changeset_discussion(user = "Steve", format = "json")
#> $version
#> [1] "0.6"
#>
#> $generator
#> [1] "OpenStreetMap server"
#>
#> $copyright
#> [1] "OpenStreetMap and contributors"
#>
#> $attribution
#> [1] "http://www.openstreetmap.org/copyright"
#>
#> $license
#> [1] "http://opendatacommons.org/licenses/odbl/1-0/"
#>
#> $comments
#> $comments[[1]]
#> $comments[[1]]$id
#> [1] 664366
#>
#> $comments[[1]]$visible
#> [1] TRUE
#>
#> $comments[[1]]$date
#> [1] "2021-02-25T19:31:46Z"
#>
#> $comments[[1]]$uid
#> [1] 1
#>
#> $comments[[1]]$user
#> [1] "Steve"
#>
#> $comments[[1]]$text
#> [1] "woo!"
#>
#>
#>
# Search for changeset comments between January 1st and January 2nd, 2015:
osm_search_comment_changeset_discussion(from = "2015-01-01", to = "2015-01-02", format = "xml")
#> {xml_document}
#> <osm version="0.6" generator="OpenStreetMap server" copyright="OpenStreetMap and contributors" attribution="http://www.openstreetmap.org/copyright" license="http://opendatacommons.org/licenses/odbl/1-0/">
#> [1] <comment id="3597" date="2015-01-01T23:41:30Z" visible="true" uid="10915 ...
#> [2] <comment id="3596" date="2015-01-01T23:36:36Z" visible="true" uid="88164 ...
#> [3] <comment id="3595" date="2015-01-01T23:29:40Z" visible="true" uid="88164 ...
#> [4] <comment id="3594" date="2015-01-01T23:24:27Z" visible="true" uid="61942 ...
#> [5] <comment id="3593" date="2015-01-01T23:19:58Z" visible="true" uid="88164 ...
#> [6] <comment id="3592" date="2015-01-01T23:15:54Z" visible="true" uid="23858 ...
#> [7] <comment id="3591" date="2015-01-01T23:15:38Z" visible="true" uid="39688 ...
#> [8] <comment id="3590" date="2015-01-01T23:12:25Z" visible="true" uid="61942 ...
#> [9] <comment id="3589" date="2015-01-01T22:23:35Z" visible="true" uid="61942 ...
#> [10] <comment id="3588" date="2015-01-01T22:14:08Z" visible="true" uid="61942 ...
#> [11] <comment id="3587" date="2015-01-01T21:53:43Z" visible="true" uid="18850 ...
#> [12] <comment id="3586" date="2015-01-01T21:53:40Z" visible="true" uid="61942 ...
#> [13] <comment id="3585" date="2015-01-01T21:29:38Z" visible="true" uid="33121 ...
#> [14] <comment id="3584" date="2015-01-01T20:30:27Z" visible="true" uid="25485 ...
#> [15] <comment id="3583" date="2015-01-01T19:49:08Z" visible="true" uid="23858 ...
#> [16] <comment id="3582" date="2015-01-01T19:40:03Z" visible="true" uid="12992 ...
#> [17] <comment id="3581" date="2015-01-01T19:39:16Z" visible="true" uid="12992 ...
#> [18] <comment id="3580" date="2015-01-01T17:53:47Z" visible="true" uid="13112 ...
#> [19] <comment id="3579" date="2015-01-01T16:35:02Z" visible="true" uid="10915 ...
#> [20] <comment id="3578" date="2015-01-01T16:23:43Z" visible="true" uid="61942 ...
#> ...