Search changeset comments
Source:R/osmapi_changeset_discussion.R
osm_search_comment_changeset_discussion.RdReturns changeset comments that match the specified query. If no query is provided, the most recent changeset comments are returned.
Usage
osm_search_comment_changeset_discussion(
user,
from,
to,
format = c("R", "xml", "json"),
tags_in_columns = FALSE
)Arguments
- user
Search for changeset comments created by the user with the given user id (numeric) or display name (character).
- from
Beginning date range. See details for the valid formats.
- to
End date range. Only works when
fromis supplied. See details for the valid formats.- format
Format of the output. Can be
"R"(default),"xml", or"json".If
FALSE(default), the tags of the changesets are saved in a single list columntagscontaining adata.framefor each changeset with the keys and values. IfTRUE, add a column for each key. Ignored ifformat != "R".
Value
If format = "R", returns a data frame with one comment per If format = "xml", returns a
xml2::xml_document. If format = "json", returns a list with the json structure.
Details
The valid formats for from and to parameters are POSIXt values or characters preferably in
ISO 8601 format.
See also
Other changeset discussion's functions:
osm_comment_changeset_discussion(),
osm_hide_comment_changeset_discussion(),
osm_subscribe_changeset_discussion()
Examples
# See the latest changeset comments globally:
osm_search_comment_changeset_discussion()
#> id date visible uid user
#> 1 1613766 2026-06-18 09:57:34 TRUE 20144444 MappingMore
#> 2 1613765 2026-06-18 09:45:47 TRUE 20577594 birimkulova
#> 3 1613764 2026-06-18 09:45:26 TRUE 1722488 Mateusz Konieczny
#> 4 1613763 2026-06-18 09:43:17 TRUE 20577594 birimkulova
#> 5 1613762 2026-06-18 09:39:33 TRUE 1722488 Mateusz Konieczny
#> 6 1613761 2026-06-18 09:18:15 TRUE 23603490 VLD0251
#> 7 1613760 2026-06-18 09:17:02 TRUE 24225476 Steve Trumpton
#> 8 1613759 2026-06-18 09:12:32 TRUE 22984868 Geocrest
#> 9 1613758 2026-06-18 09:12:19 TRUE 20051395 ajmat
#> 10 1613757 2026-06-18 09:10:59 TRUE 10914070 Yog Sot
#> 11 1613756 2026-06-18 09:10:00 TRUE 23896451 CAM-Gerlach_Revert
#> 12 1613755 2026-06-18 09:08:02 TRUE 23896451 CAM-Gerlach_Revert
#> 13 1613754 2026-06-18 09:04:52 TRUE 197244 JeroenHoek
#> 14 1613753 2026-06-18 09:04:12 TRUE 23896451 CAM-Gerlach_Revert
#> 15 1613752 2026-06-18 09:00:03 TRUE 23896451 CAM-Gerlach_Revert
#> 16 1613751 2026-06-18 08:59:27 TRUE 197244 JeroenHoek
#> 17 1613750 2026-06-18 08:58:38 TRUE 305854 salgo60
#> 18 1613749 2026-06-18 08:58:05 TRUE 370729 Jan Olieslagers
#> 19 1613748 2026-06-18 08:57:49 TRUE 23896451 CAM-Gerlach_Revert
#> 20 1613747 2026-06-18 08:57:49 TRUE 8923706 Elizen
#> 21 1613746 2026-06-18 08:56:16 TRUE 69628 vsandre
#> 22 1613745 2026-06-18 08:56:02 TRUE 686490 hatul
#> 23 1613744 2026-06-18 08:51:32 TRUE 20051396 rajdhani
#> 24 1613743 2026-06-18 08:51:00 TRUE 23896451 CAM-Gerlach_Revert
#> 25 1613742 2026-06-18 08:50:59 TRUE 23603490 VLD0251
#> 26 1613741 2026-06-18 08:49:04 TRUE 24217642 josm19902026
#> 27 1613740 2026-06-18 08:48:49 TRUE 11231605 Gilbert84
#> 28 1613739 2026-06-18 08:48:18 TRUE 23896451 CAM-Gerlach_Revert
#> 29 1613738 2026-06-18 08:48:06 TRUE 23896451 CAM-Gerlach_Revert
#> 30 1613737 2026-06-18 08:45:35 TRUE 11220113 ivanbranco
#> 31 1613736 2026-06-18 08:43:44 TRUE 1722488 Mateusz Konieczny
#> 32 1613735 2026-06-18 08:42:03 TRUE 23896451 CAM-Gerlach_Revert
#> 33 1613734 2026-06-18 08:40:08 TRUE 23896451 CAM-Gerlach_Revert
#> 34 1613733 2026-06-18 08:39:13 TRUE 20051395 ajmat
#> 35 1613732 2026-06-18 08:38:40 TRUE 23896451 CAM-Gerlach_Revert
#> 36 1613731 2026-06-18 08:37:22 TRUE 23896451 CAM-Gerlach_Revert
#> 37 1613730 2026-06-18 08:35:12 TRUE 1722488 Mateusz Konieczny
#> 38 1613729 2026-06-18 08:34:58 TRUE 23896451 CAM-Gerlach_Revert
#> 39 1613728 2026-06-18 08:33:03 TRUE 23896451 CAM-Gerlach_Revert
#> 40 1613727 2026-06-18 08:31:10 TRUE 598860 Marek-M
#> 41 1613726 2026-06-18 08:30:43 TRUE 12121975 De mammoet
#> 42 1613725 2026-06-18 08:29:37 TRUE 6106928 paneva
#> 43 1613724 2026-06-18 08:28:41 TRUE 21392280 CAM-Gerlach
#> 44 1613723 2026-06-18 08:27:18 TRUE 8716397 f_gonella
#> 45 1613722 2026-06-18 08:25:42 TRUE 10098044 Ernie C
#> 46 1613721 2026-06-18 08:24:38 TRUE 1944033 Dodko
#> 47 1613720 2026-06-18 08:21:35 TRUE 23326749 DSW21F
#> 48 1613719 2026-06-18 08:17:54 TRUE 23603490 VLD0251
#> 49 1613718 2026-06-18 08:17:31 TRUE 12121975 De mammoet
#> 50 1613717 2026-06-18 08:16:57 TRUE 598860 Marek-M
#> 51 1613716 2026-06-18 08:16:56 TRUE 21603630 Filippo Bianchi
#> 52 1613715 2026-06-18 08:16:37 TRUE 6406545 Sammyhawkrad
#> 53 1613714 2026-06-18 08:16:32 TRUE 23366256 mute44
#> 54 1613713 2026-06-18 08:12:26 TRUE 255730 -=|MisterY|=-
#> 55 1613712 2026-06-18 08:10:04 TRUE 11758604 map per
#> 56 1613711 2026-06-18 08:10:02 TRUE 23608815 9_tab
#> 57 1613710 2026-06-18 08:07:27 TRUE 3951648 rskedgell
#> 58 1613709 2026-06-18 08:06:29 TRUE 38313 SKald
#> 59 1613708 2026-06-18 08:03:25 TRUE 18526183 yelisey90
#> 60 1613707 2026-06-18 08:02:40 TRUE 6406545 Sammyhawkrad
#> 61 1613706 2026-06-18 07:59:01 TRUE 6406545 Sammyhawkrad
#> 62 1613705 2026-06-18 07:57:35 TRUE 18526183 yelisey90
#> 63 1613704 2026-06-18 07:56:26 TRUE 337375 Rom1
#> 64 1613703 2026-06-18 07:54:55 TRUE 9494130 grzegorzmilosz
#> 65 1613702 2026-06-18 07:53:58 TRUE 337375 Rom1
#> 66 1613701 2026-06-18 07:47:29 TRUE 1722488 Mateusz Konieczny
#> 67 1613700 2026-06-18 07:46:39 TRUE 1722488 Mateusz Konieczny
#> 68 1613699 2026-06-18 07:46:12 TRUE 18526183 yelisey90
#> 69 1613698 2026-06-18 07:45:11 TRUE 1722488 Mateusz Konieczny
#> 70 1613697 2026-06-18 07:43:43 TRUE 3951648 rskedgell
#> 71 1613696 2026-06-18 07:34:24 TRUE 255730 -=|MisterY|=-
#> 72 1613695 2026-06-18 07:30:39 TRUE 23608815 9_tab
#> 73 1613694 2026-06-18 07:30:37 TRUE 917603 PPete2
#> 74 1613693 2026-06-18 07:30:02 TRUE 20051396 rajdhani
#> 75 1613692 2026-06-18 07:24:25 TRUE 22991521 rubu3000
#> 76 1613691 2026-06-18 07:24:11 TRUE 526044 donux-nl
#> 77 1613690 2026-06-18 07:21:42 TRUE 18526183 yelisey90
#> 78 1613689 2026-06-18 07:17:47 TRUE 19534428 PluMGMK
#> 79 1613688 2026-06-18 07:11:28 TRUE 334075 eggie
#> 80 1613687 2026-06-18 07:07:41 TRUE 19218869 hahae
#> 81 1613686 2026-06-18 07:07:00 TRUE 19218869 hahae
#> 82 1613685 2026-06-18 07:06:58 TRUE 334075 eggie
#> 83 1613684 2026-06-18 07:05:56 TRUE 197244 JeroenHoek
#> 84 1613683 2026-06-18 07:05:27 TRUE 197244 JeroenHoek
#> 85 1613682 2026-06-18 06:59:22 TRUE 3298438 aixbrick
#> 86 1613681 2026-06-18 06:58:42 TRUE 20051396 rajdhani
#> 87 1613680 2026-06-18 06:48:36 TRUE 16260494 Anas masuris
#> 88 1613679 2026-06-18 06:48:08 TRUE 5127355 aTarom
#> 89 1613678 2026-06-18 06:47:37 TRUE 9397924 Edelsalami
#> 90 1613677 2026-06-18 06:47:31 TRUE 127573 wilda69
#> 91 1613676 2026-06-18 06:47:30 TRUE 23896451 CAM-Gerlach_Revert
#> 92 1613675 2026-06-18 06:44:37 TRUE 127573 wilda69
#> 93 1613674 2026-06-18 06:41:15 TRUE 334075 eggie
#> 94 1613673 2026-06-18 06:41:04 TRUE 24217642 josm19902026
#> 95 1613672 2026-06-18 06:39:58 TRUE 22197013 Bartekkmee
#> 96 1613671 2026-06-18 06:14:06 TRUE 23266368 uk_mapfan_2025
#> 97 1613670 2026-06-18 06:06:01 TRUE 20051396 rajdhani
#> 98 1613669 2026-06-18 06:04:07 TRUE 20144444 MappingMore
#> 99 1613668 2026-06-18 06:01:53 TRUE 2815652 gion274
#> 100 1613667 2026-06-18 06:01:32 TRUE 718122 YomanNH
#> comment_text
#> 1 Revert of https://www.openstreetmap.org/changeset/184232684
#> 2 hello\t\nThank you for the comment, I’ll take it into account. Thanks!
#> 3 https://www.openstreetmap.org/way/722965375/history - what this object is supposed to represent?
#> 4 Hi. Thank you for the comment, I’ll take it into account. Thanks!
#> 5 Can you take look at https://www.openstreetmap.org/note/5005578 ?
#> 6 @josm19902026, your response ignores undeniable technical and behavioral evidence. using the advanced JOSM editor in French from your very first edit is a technical signature identical to that of test0022012, mega1999, and dark-falcon-osm, which is highly unusual for a beginner. furthermore, your contributions on Way osm.org/way/1530515587 and Way osm.org/way/1524051336 mimic the exact same geographic area, editing style, and tagging methods as your blocked accounts.
#> 7 Thanks Bernard. There is a temporary path that is partially accessible. I'll walk it with the GPS and upload shortly.
#> 8 Hi felipeeugenio, Thank you for your feedback. I will analyze the situation and come back to you.
#> 9 Reverted in changeset id: https://www.openstreetmap.org/changeset/184261492
#> 10 wiesz, jest czerwiec. Takie ściezki trza zimą sprawdzac;]
#> 11 Cleaned up SEO-spammy and other tags for POI in changeset 184261467\n\nhttps://osm.org/changeset/184261467
#> 12 Cleaned up SEO-spammy and other tags for POI in changeset 184261368\n\nhttps://osm.org/changeset/184261368
#> 13 Maar is dat relevante informatie voor het object zelf? Daarnaast is een tag als 'nvwa_toezicht' een tag die alleen in de Nederlandse context klopt (een Nederlandse instantie plus een Nederlands woord). De richtlijn is om tags juist generiek te maken.
#> 14 Split SEO POI details from building to node given it is occupied by other tenants, and cleaned up SEO-spammy tags for "Kofler-Dichtungen" office in changeset 184261221\n\nhttps://osm.org/changeset/184261221
#> 15 Added appropriate top-level tags and cleaned up SEO-spammy name=* in changeset 184261043\n\nhttps://osm.org/changeset/184261043
#> 16 Wanneer het om grote objecten gaat waar het terrein ook relevant is, mag vlaktagging ook. Voor ziekenhuizen en scholen is dat gebruikelijk, bij man_made=works en andere grote industriezaken past het ook goed. Het is niet verplicht het zo te doen, maar als het zo al ingetekend is, is het niet netjes om dat terug te draaien. Je gaat dan van meer detail naar minder detail namelijk.
#> 17 Fråga på https://forum.openstreetmap.org/ är mitt tips ;-) \n\nJag städade OSM från borttagna WD objekt se https://github.com/salgo60/Stockholm_Archipelago_Trail/issues/415
#> 18 Well, if it is no longer an aerodrome, then the proper handling is to tag both the aerodrome and the runway with "disused" - this will avoid others adding it again.
#> 19 A number of tags here were malformed (building=*, etc) which were fixed in other changesets, and I cleaned up the remaining SEO-spammy bits in changeset 184260944\n\nhttps://osm.org/changeset/184260944
#> 20 You're right. I fixed it
#> 21 Ist das beabsichtigt, dass die Straße eine Adresse bekommen hat?\nhttps://www.openstreetmap.org/way/113730102\nSieht für mich nicht passend aus.
#> 22 טוב שתיקנת את היחס.\nאבל בטוח היה שם סימון כחול, אני לא ממפה סתם.\nאני מקווה להיות שם בקרוב ואז אבדוק.
#> 23 Partially reverted in changeset id: 184260672
#> 24 A number of tags here were malformed (opening_hours=*, phone=*, etc) which were fixed in other changesets, and I cleaned up the SEO-spammy name=* in changeset 184260640\n\nhttps://osm.org/changeset/184260640
#> 25 Hello! Thanks for your mapping work in this area. I noticed that you’ve added a lot of waterway=dam tags.\n\nosm.org/#map=14/32.37221/14.19047\n\nPlease reserve dam for large dams.\n\nHappy mapping!
#> 26 "I'm sorry, my friend, but it seems there's been a misunderstanding. I checked all the accounts you attributed to me, and I was honestly surprised. What truly saddened me was seeing the account (test0022012) banned, especially since it looks like it has been active on the site since 2015. As for the accounts (mega1999) and (falcon-osm), I couldn't find much information on them, and I honestly don't know on what basis all these accounts were linked to me."
#> 27 If you see the latest satellite imagery e.g. Esri, the texture now looks more like scrub.
#> 28 It seems you changed the address of this existing building, rather than moving the actual POI--which in any case appears to be only one unit of this building and should be a separate node rather than tagging the entire building with it, is missing any top-level tags describing what it actually is, and has the building:units=* tag used when I _think_ you probably mean addr:unit=*, as well as not using the common name=* of the business (without GmbH).\n\nTherefore, I've had to revert this change, as well as the original. in changeset 184260525\n\nhttps://osm.org/changeset/184260525\n\nYou can add the POI at the new location, provided you are careful to use correct tagging and tag it as a node rather than the entire building way.
#> 29 It seems you changed the address of this existing building, rather than moving the actual POI--which in any case appears to be only one unit of this building and should be a separate node rather than tagging the entire building with it, is missing any top-level tags describing what it actually is, and has the building:units=* tag used when I _think_ you probably mean addr:unit=*, as well as not using the common name=* of the business (without GmbH).\n\nTherefore, I've had to revert this change, as well as the original. in changeset 184260525\n\nhttps://osm.org/changeset/184260525\n\nYou can add the POI at the new location, provided you are careful to use correct tagging, not reference Google Maps, etc., and tag it as a node rather than the entire building way.
#> 30 Penso stia utilizzando l'estensione di julcnx: https://github.com/julcnx/strava-heatmap-extension
#> 31 https://www.openstreetmap.org/node/4238370274/history\n\nwhy you added delivery=only ?\n\nit makes no sense with shop=clothes
#> 32 Reverted adding SEO POI with malformed tags (name=*, opening_hours=*, phone=*) and source=* of Google Maps, which is not allowed by both OSM and Google policies (see https://osm.wiki/Google ), in changeset 184260267\n\nhttps://osm.org/changeset/184260267
#> 33 Reverted adding SEO POI with malformed tags (name=*, opening_hours=*, phone=*) and source=* of Google Maps, which is not allowed by both OSM and Google policies (see https://osm.wiki/Google ), in changeset 184260189\n\nhttps://osm.org/changeset/184260189
#> 34 Reverted in changeset id: https://www.openstreetmap.org/changeset/184260129
#> 35 Reverted adding SEO POI with malformed tags (name=*) and source=* of Google Maps, which is not allowed by both OSM and Google policies (see https://osm.wiki/Google ), in changeset 184260133\n\nhttps://osm.org/changeset/184260133
#> 36 Reverted adding SEO POI with malformed tags (name=*, opening_hours=*) and source=* of Google Maps, which is not allowed by both OSM and Google policies (see https://osm.wiki/Google ), in changeset 184260093\n\nhttps://osm.org/changeset/184260093
#> 37 I deleted it then
#> 38 Reverted adding SEO spam POI with malformed tags (name=*, opening_hours=*) and source=* of Google Maps, which is not allowed by both OSM and Google policies (see https://osm.wiki/Google ), in changeset 184260023\n\nhttps://osm.org/changeset/184260023
#> 39 Revert changeset 180446837 which added a SEO POI with several malformed tags (name=*, opening_hours=*, wikidata=*, etc) and added apparent housenumbers to a highway name=*, in changeset 184259932\n\nhttps://osm.org/changeset/184259932
#> 40 Może nie wiedziałeś tego ale tworzenie dwóch linii przy tych mikrowysepkach wymaga dodatkowego podziału dróg i utworzenia dodatkowych 6 restrykcji:\nhttps://i.imgur.com/D0tK4lO.png\n\nPoprawiłem to w CS: https://www.openstreetmap.org/changeset/184259630 i https://www.openstreetmap.org/changeset/184259674
#> 41 Dag Jeroen,\nHet is mij niet duidelijk wanneer je iets op het adres tagt en wanneer niet. Ik hoor steeds iets anders en dacht te lezen dat er consensus is dit op de adres nodes wordt gedaan in Nederland. Ik zal voor grote terreinen wel weer ways hanteren.
#> 42 Thank you for the informative answer! I will be taking these on board for the future
#> 43 > 1) It re-uses the node for the address of the building, building with has multiple tenants. If the POI is to be created, it should be separate.\n\nThanks! This was what I was referring to with "Swiss local convention on POIs/addresses that I'm unaware of ". Where I map, the standard best practice is to put a building-level address on the building way, with POIs as nodes (also with an address, with addr:unit=* if known), but I'm assuming Swiss convention is different--as each European country seems to have a different convention on this, I left it to local mappers like yourself to comment on this aspect.\n\n> 2) It's unclear if the business has a physical presence at the location. A survey didn't find it.\n\nHmm, I see. At least according to their website, https://hypnonaute.com/contact they claim to primarily offer in-person services inside this building (as opposed to a number of SEO POIs I remove). Perhaps the office space is shared or not formally signed (which would be a judgement call on whether it should be mapped)? Up to you of course as the local mapper how you'd like to handle it if you aren't able to verify it on the ground.\n\n> 3) It's unclear if the business actually exists (it's not in online databases I checked).\n\nHmm, well it seems unlikely to me they'd be spending this much time and effort (substantially more than the average hit and run SEO spammer I deal with) advertising a business requiring in-person interaction that doesn't actually exist at all. But I suppose one never knows these days :)
#> 44 Hi @SekeRob, how did you manage to set up 🔥 Strava Heatmap All Sports as a background image for mapping? Could you please advise? Thanks!
#> 45 Mijn excuses. Ik was blijkbaar iets te enthousiast met dingen veranderen. Bedankt voor de feedback.
#> 46 Opravený preklep\nhttps://www.openstreetmap.org/way/1529698865/history
#> 47 Hallo,\nGedanke hinter den beiden NEUEN POI´s war eine bessere Auffindbarkeit des "Zoo Dortmund" in der für Dortmund relevanten Fahrplanauskunft des VRR. \nHier ist eine Auffindbarkeit eines POIs des ausschlaggebenden Attributs "Tourism: Zoo" Voraussetzung. Entsprechend habe zwei neue POIs mit den Entsprechenden Attributen auf die Eingänge des Zoo Dortmund gelegt.\nFür den Haupteingang des Zoos stimmt die Attributtierung mit "Shop: Ticket" nicht, da der eigentliche Ticketshop im Gebäude davor liegt.\nMein Vorschlag wäre daher, den POI mit Attribut "Tourism: Zoo" auf dem eigentlichen Eingang zu lassen und den Ticketshop an der eigentlichen Position zu ergänzen.\nViele Grüße
#> 48 @josm19902026, evading blocks through sockpuppetry is strictly prohibited on OpenStreetMap. this is your 4th account (previous accounts: dark-falcon-osm, mega1999, test0022012)\nPlease comply with your original bans or reach out directly to the Data Working Group (DWG)
#> 49 De NVWA hanteert drie slachthuis categoriën die worden bepaald door de slachtsnelheid. Hiermee kan duidelijk onderscheid in de grote worden gemaakt.\nhttps://www.nvwa.nl/onderwerpen/dier/slachthuis-uitsnijderij/toezicht-bij-slachthuizen
#> 50 Cześć, dlaczego rysujesz oddzielną linią DDR i chodnik, gdy pomiędzy nimi nie ma podziału fizycznego? Takie pomysły drogowców, jak np. przy ul. Kościuszki, Promenada powinny być rysowane jedną linią highway=path z dodatkowym tagowaniem jak na wiki:\nhttps://wiki.openstreetmap.org/wiki/Pl:Rowery#Drogi_dla_pieszych_i_rowerów
#> 51 Questa modifica è relativa alla nota: \n#3639180
#> 52 Hi monsoonheat, welcome to OSM. Roads shouldn't cross buildings, so avoid that when mapping. JOSM will always show that as a warning, so fix them before you upload.
#> 53 Voila c'est corrigé dans https://www.openstreetmap.org/changeset/184259315\nDésolé pour le dérangement
#> 54 Most likely I've used the info from Bergsteigen at the time.
#> 55 Hallo Openminded320,\n\nist https://www.openstreetmap.org/node/13295435850 wirklich eine tourism=wilderness_hut mit Schlafplätzen zum Übernachten, oder ist das eher ein amenity=shelter ?\n\nDanke und viele Grüße\nmap per\n
#> 56 With (3.), I was trying to say that I don't think https://www.flixbus.de/track shows the actual route. You could check it by searching for street segments in your area that have temporary restrictions or recent constructional changes.\n\nFor (6.), I'd add the description="The start, end, and stop locations have not been verified. This route may be out of service for an extended period and may not match the actual route."\n\nFor (7.), it might make sense to handle the ones you follow in detail differently from others. I had contacted the mapper who created some around Geneva. Apparently, he hadn't been maintained them since Covid. In general, OSM seems to prefer not to include historic bus routes.
#> 57 (Review requested)\n\nChanging the address tags on the POI doesn't actually move it on the map.\n\nDoes this mean that the premises at 48 Porchester Road W2 6ET are no longer occupied by your business and that you are now trading from 58-60 George Street W1U 7ET ? If this is the case, the tags relating to you business need to be removed from the old location and added to the new location.\n\nThe new location was mapped in 2019 with Daniel Galvin's salon as the occupier - https://www.openstreetmap.org/way/148008521\n\nIf you'd like any help updating this, please reply here and I'll be happy to make these changes for you.
#> 58 why did you put the start of the "Lärchkogelgrat"-Tour at this place? I'd start at the south/east-end of the parking, but haven't done so for several years now. Has it changed?
#> 59 Partly reverted & fixed: https://www.openstreetmap.org/changeset/184258816\nThe northern part is clearly not indented for vehicles (maybe it used for them during the construction of the playground, but not more). And it visibly differs in surface, so in any case it's better not to merged them in one way.
#> 60 Hi BinkalB, building=1 is not a valid tag. Use building=yes
#> 61 Hi Mensah Silas, welcome to OSM. Please take a critical look before you upload/save what you map. I doubt you'd find a building in the middle of the road.
#> 62 Please note that you have left the relation an unenclosed inner border. It needs to be fixed\nhttps://www.openstreetmap.org/relation/15419576
#> 63 Par définition footway interdit la circulation à vélo.
#> 64 wprowadzone przeze mnie wysepki są zgodne z definicją z OSM wiki mówiącą iż traffic_calming=island służy do oznaczenia obszaru który na krótkim odcinku rozdziela dwa różne kierunki ruchu. Wyspa ta rozdziela co najmniej dwa pasy ruchu od siebie na niewielkiej odległości. Szerokość jej jest zazwyczaj do kilku metrów i powinna być mniejsza niż 5 metrów. Wszystkie oznaczone przeze mnie wysepki posiadają wysokie krawężniki i fizycznie rozdzielają ruch zgodnie z ww. definicją. Nie oznaczałem wysepek plastikowych przykręcanych do asfaltu czy też wysepek o znikomym krawężniku gdyż takie nie zapewniają fizycznej separacji. oznaczone zostały przeze mnie tylko wysepki permanentne. Wysepki te maja ponad 10 m każda.
#> 65 Bonjour, j'ai remis supermarket à https://www.openstreetmap.org/way/722979213 convenience est réservé aux petits commerces https://wiki.openstreetmap.org/wiki/FR:Tag:shop%3Dconvenience
#> 66 or maybe even skip mapping this if it is only for internal use...
#> 67 https://www.openstreetmap.org/node/13944285460/history\n\nis there reason to not use simply access=private here?
#> 68 Why have you created two additional nodes for fuel stations when there was already a polygon for it, https://www.openstreetmap.org/way/1167371838 ? Are these different stations? If not, please delete them.
#> 69 putting bare construction=yes on https://www.openstreetmap.org/node/186660855/history will not change anything\n\nis it a long-term construction? Then changing relevant road lines to "Road under construction" (highway=construction) would work
#> 70 For https://www.openstreetmap.org/way/844475987 to be a sidewalk, it needs a road to be the sidewalk of. Updated in https://www.openstreetmap.org/changeset/184258168
#> 71 Thank you! Fixed.
#> 72 Not really convinced. I see three issues:\n\n1) It re-uses the node for the address of the building, building with has multiple tenants. If the POI is to be created, it should be separate.\n\n2) It's unclear if the business has a physical presence at the location. A survey didn't find it.\n\n3) It's unclear if the business actually exists (it's not in online databases I checked).
#> 73 Please have a look at: https://www.openstreetmap.org/note/5098168
#> 74 Reverted in changeset id:184257726
#> 75 Yes, they are the official names.
#> 76 Dag Emvee,\nDe situatie in dit deel is tijdelijk gewijzigd. Het zuidelijke fietspad van de Burg Brokxlaan is deels afgesloten en de zuidelijke weghelft is in gebruik als fietspad. Dit is zeker tot 4/6/2027 volgens https://bereikbaarheid.andes.nl/. \nLijkt me wel de moeite om dit aan te passen, aangezien het voor een jaar is.
#> 77 reverted - these are not parking_aisles , please re-read it carefully: https://wiki.openstreetmap.org/wiki/Tag:service=parking_aisle#Disambiguation\n\nhttps://www.openstreetmap.org/changeset/184257432
#> 78 Hi! Yeah, because of the different offsets on newer imagery, someone had added four "trees" that were actually pylons I had already mapped.\n\nThinking about it now, it might have been AI-assisted...
#> 79 warnings:crossing_ways:building-highway \t6\nwarnings:crossing_ways:highway-highway \t26\n\nDe schade is weer hersteld.
#> 80 关于公交关系,您可以参考 https://wiki.openstreetmap.org/wiki/Zh-hans:%E5%85%AC%E4%BA%A4\n\n感谢您的贡献
#> 81 抱歉,是我的问题,记得加name:en 时候同时添加name:zh就好
#> 82 Welkom bij OSM,\n\nAlle begin is moeilijk, maar hier is wel schade ontstaan aan de kaart.. waarschijnlijk door schuiven met de kaart in editmodus.\nJe edits https://resultmaps.neis-one.org/osm-change-viz?c=184256734#15/51.6891/5.2762\nMVG\neggie
#> 83 Zou je hier nog even op willen terugkomen?
#> 84 Bij een groot complex zoals industrial=slaughterhouse is taggen op een vlak niet per se verkeerd (in tegenstelling tot winkels e.d.). Waarom verwijder je de ruimtelijke informatie hier?
#> 85 Danke. Bei OSM ist natürlich immer auch eine gewisse Abstraktion im Spiel ;-).\nDas Tag dient im Wesentlichen dazu festzulegen, dass der Weg im Bereich des Gebäudeumrisses durch das Gebäude verläuft und nicht oberhalb (layer=1) oder unterhalb (layer=-1). Das ist vor allem fürs Rendering wichtig.
#> 86 Reverted in changeset id:184256724
#> 87 Jakiś link do tej strony z informacjami dot. l. pierwszorzędnych (bo te linie są pierwszorzędne)? Bo akurat w papierologii PKP PLK siedzę od jakiegoś czasu i chyba nie wiem, o czym jest mowa\n\nSam fakt, że linia jest pierwszorzędna nie jest jednoznacznie równoznaczne z tym, że wg klasyfikacji OSM linie te mają być zdegradowane do usage=branch (chyba najlepszym przykładem są LK7, LK11 i LK26, które mają podobne klasyfikacje, co zmienione linie kolejowe)
#> 88 Hola, retiro los tags\n> HECTARIAS\n> id\n> perimetro\n> union\nde\nhttps://www.openstreetmap.org/way/1530514206/history\nSaludos
#> 89 Hallo skycastle66, du hast hier fälschlicherweise ein Wald-Polygon als Zaun gemappt. Ich nehme an, das war ein Versehen? Ich mache deine Änderung rückgängig. \nGruß
#> 90 btw its difficult to say how long it was like this. The area around the chalets is all grass and was cut but strikingly no sign of a former path
#> 91 The address may have changed, but it seems you didn't actually move the POI to the new location...
#> 92 Hi Jass,\nWe walked from the pub towards Bayview but at the end of this road we were met by a wooden fence down to the cliff separating the chalets. There was no sign of any path on the other side of the fence. I have plotted the CP along the footway you plotted but we made our way to Willows walking in between the chalets. There were no CP signs whatsoever. It was obvious that the owner of the chalets had instigated the blockage. There was no landslip. \nCheers,\nDan
#> 93 Het voetpad (looproute) heb ik aangepast zodat het niet meer door het gebouw loopt.
#> 94 The main issue lies in the low accuracy and sheer volume of the initial drawings, making it highly time-consuming to correct them manually, point by point. We are very committed to the quality and precision of the drawings, and we thank you so much for this valuable feedback. If you have an alternative or easier way to speed up this process, we would welcome your suggestions. Thank you, my friend
#> 95 Informacje ze strony PKP PLK dotyczące linii pierwszorzednych i drugorzędnych. Mapa PKP PLK
#> 96 Meant `railway:preferred_direction=` not bidirectional tagging
#> 97 Partially reverted in changeset id: 184255295
#> 98 Reverted in https://www.openstreetmap.org/changeset/184255263
#> 99 yes, you're right, thanks, I corrected it
#> 100 Wspaniale :) Czasem coś zgłaszam, ale rzadko.
# Search for changeset comments by a specific user:
osm_search_comment_changeset_discussion(user = "Steve", format = "json")
#> $version
#> [1] "0.6"
#>
#> $generator
#> [1] "OpenStreetMap server"
#>
#> $copyright
#> [1] "OpenStreetMap and contributors"
#>
#> $attribution
#> [1] "http://www.openstreetmap.org/copyright"
#>
#> $license
#> [1] "http://opendatacommons.org/licenses/odbl/1-0/"
#>
#> $comments
#> $comments[[1]]
#> $comments[[1]]$id
#> [1] 664366
#>
#> $comments[[1]]$visible
#> [1] TRUE
#>
#> $comments[[1]]$date
#> [1] "2021-02-25T19:31:46Z"
#>
#> $comments[[1]]$uid
#> [1] 1
#>
#> $comments[[1]]$user
#> [1] "Steve"
#>
#> $comments[[1]]$text
#> [1] "woo!"
#>
#>
#>
# Search for changeset comments between January 1st and January 2nd, 2015:
osm_search_comment_changeset_discussion(from = "2015-01-01", to = "2015-01-02", format = "xml")
#> {xml_document}
#> <osm version="0.6" generator="OpenStreetMap server" copyright="OpenStreetMap and contributors" attribution="http://www.openstreetmap.org/copyright" license="http://opendatacommons.org/licenses/odbl/1-0/">
#> [1] <comment id="3597" date="2015-01-01T23:41:30Z" visible="true" uid="10915 ...
#> [2] <comment id="3596" date="2015-01-01T23:36:36Z" visible="true" uid="88164 ...
#> [3] <comment id="3595" date="2015-01-01T23:29:40Z" visible="true" uid="88164 ...
#> [4] <comment id="3594" date="2015-01-01T23:24:27Z" visible="true" uid="61942 ...
#> [5] <comment id="3593" date="2015-01-01T23:19:58Z" visible="true" uid="88164 ...
#> [6] <comment id="3592" date="2015-01-01T23:15:54Z" visible="true" uid="23858 ...
#> [7] <comment id="3591" date="2015-01-01T23:15:38Z" visible="true" uid="39688 ...
#> [8] <comment id="3590" date="2015-01-01T23:12:25Z" visible="true" uid="61942 ...
#> [9] <comment id="3589" date="2015-01-01T22:23:35Z" visible="true" uid="61942 ...
#> [10] <comment id="3588" date="2015-01-01T22:14:08Z" visible="true" uid="61942 ...
#> [11] <comment id="3587" date="2015-01-01T21:53:43Z" visible="true" uid="18850 ...
#> [12] <comment id="3586" date="2015-01-01T21:53:40Z" visible="true" uid="61942 ...
#> [13] <comment id="3585" date="2015-01-01T21:29:38Z" visible="true" uid="33121 ...
#> [14] <comment id="3584" date="2015-01-01T20:30:27Z" visible="true" uid="25485 ...
#> [15] <comment id="3583" date="2015-01-01T19:49:08Z" visible="true" uid="23858 ...
#> [16] <comment id="3582" date="2015-01-01T19:40:03Z" visible="true" uid="12992 ...
#> [17] <comment id="3581" date="2015-01-01T19:39:16Z" visible="true" uid="12992 ...
#> [18] <comment id="3580" date="2015-01-01T17:53:47Z" visible="true" uid="13112 ...
#> [19] <comment id="3579" date="2015-01-01T16:35:02Z" visible="true" uid="10915 ...
#> [20] <comment id="3578" date="2015-01-01T16:23:43Z" visible="true" uid="61942 ...
#> ...