Search changeset comments
Source:R/osmapi_changeset_discussion.R
osm_search_comment_changeset_discussion.RdReturns changeset comments that match the specified query. If no query is provided, the most recent changeset comments are returned.
Usage
osm_search_comment_changeset_discussion(
user,
from,
to,
format = c("R", "xml", "json"),
tags_in_columns = FALSE
)Arguments
- user
Search for changeset comments created by the user with the given user id (numeric) or display name (character).
- from
Beginning date range. See details for the valid formats.
- to
End date range. Only works when
fromis supplied. See details for the valid formats.- format
Format of the output. Can be
"R"(default),"xml", or"json".If
FALSE(default), the tags of the changesets are saved in a single list columntagscontaining adata.framefor each changeset with the keys and values. IfTRUE, add a column for each key. Ignored ifformat != "R".
Value
If format = "R", returns a data frame with one comment per If format = "xml", returns a
xml2::xml_document. If format = "json", returns a list with the json structure.
Details
The valid formats for from and to parameters are POSIXt values or characters preferably in
ISO 8601 format.
See also
Other changeset discussion's functions:
osm_comment_changeset_discussion(),
osm_hide_comment_changeset_discussion(),
osm_subscribe_changeset_discussion()
Examples
# See the latest changeset comments globally:
osm_search_comment_changeset_discussion()
#> id date visible uid user
#> 1 1598584 2026-05-23 09:27:23 TRUE 7543375 kapazao
#> 2 1598583 2026-05-23 09:21:42 TRUE 23608815 9_tab
#> 3 1598582 2026-05-23 09:21:38 TRUE 6193195 Manuel H
#> 4 1598581 2026-05-23 09:15:30 TRUE 13816320 DracarysX
#> 5 1598580 2026-05-23 09:14:01 TRUE 6193195 Manuel H
#> 6 1598579 2026-05-23 09:11:26 TRUE 6794624 Comino
#> 7 1598578 2026-05-23 08:53:57 TRUE 21799036 Paweł_M
#> 8 1598577 2026-05-23 08:46:07 TRUE 24147766 SjoerdvanderHeide
#> 9 1598576 2026-05-23 08:43:31 TRUE 1722488 Mateusz Konieczny
#> 10 1598575 2026-05-23 08:40:11 TRUE 3754310 rhhs
#> 11 1598574 2026-05-23 08:38:55 TRUE 1722488 Mateusz Konieczny
#> 12 1598573 2026-05-23 08:37:12 TRUE 10893436 Dimitar155
#> 13 1598572 2026-05-23 08:34:27 TRUE 24147766 SjoerdvanderHeide
#> 14 1598571 2026-05-23 08:32:10 TRUE 334075 eggie
#> 15 1598570 2026-05-23 08:27:24 TRUE 22930428 Toli99
#> 16 1598569 2026-05-23 08:23:43 TRUE 20051396 rajdhani
#> 17 1598568 2026-05-23 08:23:01 TRUE 24150123 VictorClaessen
#> 18 1598567 2026-05-23 08:22:36 TRUE 24150123 VictorClaessen
#> 19 1598566 2026-05-23 08:17:02 TRUE 334075 eggie
#> 20 1598565 2026-05-23 08:15:23 TRUE 186981 Scalarik
#> 21 1598564 2026-05-23 08:13:43 TRUE 14944781 f_husni
#> 22 1598563 2026-05-23 08:13:22 TRUE 334075 eggie
#> 23 1598562 2026-05-23 08:12:12 TRUE 334075 eggie
#> 24 1598561 2026-05-23 08:11:57 TRUE 334075 eggie
#> 25 1598560 2026-05-23 08:10:53 TRUE 14944781 f_husni
#> 26 1598559 2026-05-23 08:07:10 TRUE 334075 eggie
#> 27 1598558 2026-05-23 07:51:47 TRUE 99299 silversurfer83
#> 28 1598557 2026-05-23 07:49:08 TRUE 99299 silversurfer83
#> 29 1598556 2026-05-23 07:47:15 TRUE 112465 tux67
#> 30 1598555 2026-05-23 07:47:13 TRUE 20051396 rajdhani
#> 31 1598554 2026-05-23 07:46:30 TRUE 99299 silversurfer83
#> 32 1598553 2026-05-23 07:40:53 TRUE 128698 balchen
#> 33 1598552 2026-05-23 07:38:54 TRUE 99299 silversurfer83
#> 34 1598551 2026-05-23 07:30:26 TRUE 564990 mavl
#> 35 1598550 2026-05-23 07:29:31 TRUE 186174 michal_f
#> 36 1598549 2026-05-23 07:25:51 TRUE 99299 silversurfer83
#> 37 1598548 2026-05-23 07:11:56 TRUE 23643298 in2itivity
#> 38 1598547 2026-05-23 07:09:14 TRUE 1212745 YraFyra
#> 39 1598546 2026-05-23 07:06:04 TRUE 334075 eggie
#> 40 1598545 2026-05-23 07:05:14 TRUE 16047452 kingkingHK
#> 41 1598544 2026-05-23 07:05:03 TRUE 16047452 kingkingHK
#> 42 1598543 2026-05-23 07:01:54 TRUE 564990 mavl
#> 43 1598542 2026-05-23 06:54:33 TRUE 564990 mavl
#> 44 1598541 2026-05-23 06:51:31 TRUE 18387043 NorthCrab_upload
#> 45 1598540 2026-05-23 06:45:24 TRUE 16047452 kingkingHK
#> 46 1598539 2026-05-23 06:31:05 TRUE 39381 DD1GJ
#> 47 1598538 2026-05-23 06:12:20 TRUE 23896451 CAM-Gerlach_Revert
#> 48 1598537 2026-05-23 06:11:33 TRUE 3735696 DwarfNebula_
#> 49 1598536 2026-05-23 06:11:27 TRUE 3735696 DwarfNebula_
#> 50 1598535 2026-05-23 06:10:46 TRUE 21392280 CAM-Gerlach
#> 51 1598534 2026-05-23 06:08:48 TRUE 2649988 FajrAl
#> 52 1598533 2026-05-23 06:05:08 TRUE 23896451 CAM-Gerlach_Revert
#> 53 1598532 2026-05-23 06:04:06 TRUE 21392280 CAM-Gerlach
#> 54 1598531 2026-05-23 05:59:02 TRUE 2649988 FajrAl
#> 55 1598530 2026-05-23 05:56:33 TRUE 23896451 CAM-Gerlach_Revert
#> 56 1598529 2026-05-23 05:53:51 TRUE 21392280 CAM-Gerlach
#> 57 1598528 2026-05-23 05:50:00 TRUE 23896451 CAM-Gerlach_Revert
#> 58 1598527 2026-05-23 05:43:59 TRUE 52626 pitscheplatsch
#> 59 1598526 2026-05-23 05:43:50 TRUE 52626 pitscheplatsch
#> 60 1598525 2026-05-23 05:42:59 TRUE 52626 pitscheplatsch
#> 61 1598524 2026-05-23 05:42:35 TRUE 52626 pitscheplatsch
#> 62 1598523 2026-05-23 05:42:04 TRUE 52626 pitscheplatsch
#> 63 1598522 2026-05-23 05:41:01 TRUE 12970344 icluf
#> 64 1598521 2026-05-23 05:39:51 TRUE 20416783 PhilPhonic
#> 65 1598520 2026-05-23 05:27:43 TRUE 20144448 World_Winner
#> 66 1598519 2026-05-23 05:22:33 TRUE 334075 eggie
#> 67 1598518 2026-05-23 05:18:35 TRUE 322785 BCNorwich
#> 68 1598517 2026-05-23 05:08:00 TRUE 974272 baprischka
#> 69 1598516 2026-05-23 05:06:59 TRUE 974272 baprischka
#> 70 1598515 2026-05-23 05:04:53 TRUE 20144448 World_Winner
#> 71 1598514 2026-05-23 05:01:21 TRUE 3754310 rhhs
#> 72 1598513 2026-05-23 04:56:25 TRUE 24099236 KoreaElliotz125
#> 73 1598512 2026-05-23 04:40:09 TRUE 2649988 FajrAl
#> 74 1598511 2026-05-23 04:38:53 TRUE 23167652 WaffleR_zero
#> 75 1598510 2026-05-23 04:14:20 TRUE 2365330 Viajero Perdido
#> 76 1598509 2026-05-23 03:40:59 TRUE 5706452 Bienson
#> 77 1598508 2026-05-23 03:36:25 TRUE 237525 aharvey
#> 78 1598507 2026-05-23 03:34:32 TRUE 237525 aharvey
#> 79 1598506 2026-05-23 03:17:57 TRUE 1717680 pitfire
#> 80 1598505 2026-05-23 03:16:08 TRUE 1293194 nevw
#> 81 1598504 2026-05-23 03:06:21 TRUE 355617 pnorman
#> 82 1598503 2026-05-23 02:16:46 TRUE 20144444 MappingMore
#> 83 1598502 2026-05-23 02:04:04 TRUE 20144444 MappingMore
#> 84 1598501 2026-05-23 01:55:23 TRUE 11604214 yoyoshka
#> 85 1598500 2026-05-23 01:32:39 TRUE 20951490 Berdly
#> 86 1598499 2026-05-23 01:07:54 TRUE 134584 ocrho
#> 87 1598498 2026-05-23 01:04:40 TRUE 20354703 fortera_au
#> 88 1598497 2026-05-23 00:53:55 TRUE 9465017 tguen
#> 89 1598496 2026-05-23 00:39:54 TRUE 22313164 旧加卷
#> 90 1598495 2026-05-23 00:29:05 TRUE 4563041 McKulkin
#> 91 1598494 2026-05-23 00:13:44 TRUE 24133750 Ralith
#> 92 1598493 2026-05-23 00:13:28 TRUE 13792107 LordGarySugar
#> 93 1598492 2026-05-23 00:07:53 TRUE 609881 jayaddison
#> 94 1598491 2026-05-22 23:46:33 TRUE 23518244 AriAlvarez
#> 95 1598490 2026-05-22 23:43:30 TRUE 609881 jayaddison
#> 96 1598489 2026-05-22 23:37:33 TRUE 23518244 AriAlvarez
#> 97 1598488 2026-05-22 23:33:53 TRUE 13792107 LordGarySugar
#> 98 1598487 2026-05-22 23:17:21 TRUE 6168709 Udarian
#> 99 1598486 2026-05-22 23:17:19 TRUE 7152372 Mxdanger
#> 100 1598485 2026-05-22 23:13:59 TRUE 29626 Carnildo
#> comment_text
#> 1 Hola, ¿y esos nombres no están en algún lugar público para consultar y verificar que son reales?\n\nEntiende que el mapa debe ser mantenible y revisable por cualquier usuario, sino llega cualquiera y añade lo que le parece.\n\nUn saludo
#> 2 Isn't this premature? Possibly it can work with https://wiki.openstreetmap.org/wiki/Key:planned:* \n\nWhat are the details of your Swisstopo and RegBL sources? This way somebody can contact them to correct it there as well.
#> 3 Hallo,\nich habe mich gewundert, warum auf einmal die Stempelstellen als blankes Icon erscheinen. \nIch halte diesen Edit für vollkommen unsinnig. Und auch unverständlich, da Jörg an der Diskussion zum korrekten Tagging der Stempelstellen beteiligt war: https://community.openstreetmap.org/t/name-tags-fur-stempelstellen-von-kommerziellen-tourenanbietern/137087\n\nDaraus resultiere der Wiki-Eintrag: https://wiki.openstreetmap.org/wiki/DE:Key:checkpoint\n\nDie Begründung für das Tagging ist auch mehr als schwach. \n\n> das schließt sich ja nicht aus, sondern spezifiziert es nochmal genauer.\n\nMeines Wissens schließt sich das sehr wohl aus. tourism und amenity sind top-level tags:\nhttps://wiki.openstreetmap.org/wiki/Top-level_tag\n\nDas eine spezifiziert nicht das andere.\nU.U. dürfen zwei davon für ein Objekt gesetzt werden, aber die treffen hier nicht zu.\n\namenities sind Orte, die ein gewisses Bedürfnis erfüllen oder einen Service anbieten. tourism gruppiert halt Orte für den Tourism, die man aus Interesse oder zum Spaß besucht. \nUnd nein, Stempelsammeln ist kein Bedürfnis. \n\n> Anscheinend gibt es auch einige Tools, die damit dann besser funktionieren, unter anderem „unser eigenes“ Nominatim und Komoot.\n\nWie schon gesagt, ist das Tagging für den Renderer und "anscheinend" klingt nicht nach Fakten. Ich nutze Komoot auch schon seit vielen Jahren und das hatte nie ein Problem mit dem alten Tagging.\n\nAuch der Wert 'checkpoint_hiking' ist komplett neu erfunden. Wie sollen andere Tools damit "besser funktionieren".\n\nAlso, bitte den changeset reverten, bevor weitere Edits das verkomplizieren.\n\nMFG,\n\nManuel Hewitt
#> 4 Super, danke Dir. Ich versuche es zu fixen. In diesem konkreten Fall sind das aus meiner Sicht auch zwei verschiedene EInheiten. Die einen sind Tritium-Säulen, die anderen Hyps. Ich versuche mich mal.\n
#> 5 Hallo,\ndas Tagging der Stempelstelle ist so falsch. Es ist keine 'amenity' und das Leerzeichen darf beim Wert da auch nicht so stehen.\nSiehe das korrekt Tagging hier:\nhttps://wiki.openstreetmap.org/wiki/DE:Key:checkpoint\n\nMFG,\nManuel
#> 6 Hi,\n\nIn your edit you use the deprecated tag "payment:bitcoin=yes".\n\nPlease DELETE the payment:bitcoin=yes tag !\nUse the "currency:XBT=yes" instead.\n\nFor more information please read: https://gitea.btcmap.org/teambtcmap/btcmap-general/wiki/Tagging-Merchants#tagging-guidance\nand https://wiki.openstreetmap.org/wiki/Bitcoin\n\nAlso include the following tags:\npayment:lightning=yes\npayment:lightning_contactless=no\npayment:onchain=no\n\nThe URL does NOT show Bitcoin acceptance by-the-way.\n\nHappy mapping,\n\nEdwin Comino\nBTC Map\nhttps://www.openstreetmap.org/user/Comino
#> 7 Budżet jest określony w https://bip.rudnik.pl/pdf/uchwaly/2026/uchwa%C5%82a%20148.pdf\nStrona 17, zadania:\n- Przebudowa ciągu drogowego dróg\ngminnych ul. Majora Hubala nr\n102703R od km 0+000 do km 3+789\nwraz z ulicą boczną od ul. Majora\nHubala nr 102781R od km 0+003 do\nkm 0+355 w miejscowości Przędzel -\nEtap II\n- Przebudowa drogi gminnej 102704R w\nPrzędzelu
#> 8 Dark hiervoor, dat is een goede tip. Ik had er al last van dat die aan elkaar zaten.
#> 9 ping?
#> 10 👍
#> 11 according to my check this route exists and change was invalid
#> 12 See shop=safety_equipment
#> 13 Top, dankjewel. Dat MTB parcours staat niet helemaal goed, dat probeerde ik te fixen, maar het ging lastig.
#> 14 Hoi.. Je kunt evt in de BAG viewer kijken of die wel voorkomt in de data. Dan zou je het kunnen laten importeren via het forum middels het draadje BAG importverzoeken.\nKijk nu via mn mobiel.\nMapse\neggie
#> 15 Ви ж написали, що тут немає "Будемена" і зараз додали знову назву.
#> 16 Partially reverted in changeset id: 183055885
#> 17 (bedankt voor de warme welkom trouwens, daar had ik mee moeten beginnen.)\n
#> 18 Er zit daar een enorm ondergronds stelsel, dat loopt naar het Huygensgebouw, het Goudsmitpaviljoen, het Transitorium, het Nanolab, het Logistiek Centrum, Mercator 3. Dat is ook allemaal niet getekend. Waarom dat ene stukje HFML-FELIX ondergronds dan eigenlijk wel? Dat doet niet echt recht aan de vorm van het gebouw.
#> 19 Bovenstaande fouten opgelost
#> 20 Heippa, service=driveway kuuluu kiinteistölle johtaville ajoväylille, ei kaikille mahdollisille pikkuteille kuten olet muokannut Vantaan ajoharjoitteluradalla.
#> 21 https://www.openstreetmap.org/node/5020275637 tolong di notice yaa. karena menurut orang lokal setempat bundaran ini sudah ditutup oleh cones.
#> 22 Je ziet zelf al de foutmeldingen.\nVermoedelijk dat MTB parcours.\nwarnings:crossing_ways:highway-highway \t1\nwarnings:crossing_ways:highway-waterway \t1
#> 23 Je edits https://overpass-api.de/achavi/?changeset=183054857
#> 24 warnings:crossing_ways:highway-highway \t1 opgelost.\n\nBijna verbinding hersteld.\nvlak Toponym losgemaakt van paden.\nPLakken kun je voorkomen door de linker alttoets te gebruiken tijden bewerken.\n\nMVG\neggie
#> 25 Hallo GrabID_FaizahM. editan sebelumnya adalah editan dari orang lokal setempat. mohon dikembalikan ke editan sebelumnya atau anda lakukan survei langsung untuk memastikan keadaan lapangan terupdate. terimakasih
#> 26 Dag Sjoerd. Je plakt de paden vast aan de landuse. Dat maakt de kaart moeilijk bewerkbaar voor medemapper,\nSvp geen landusevlakken aan de paden vastmaken.\nMVG\neggie
#> 27 Ich nochmal :)\n\nvor einiger Zeit haben "wir" (die OSM-Community) darauf geeinigt, dass einzelne Ladesäulen ein man_made=charge_point (wie bei Zapfsäulen) sind und dann alle gemeinsam eine amenity=charging_station bilden (wenn sie denn zusammengehören).\n\nGrüße\n\nsilversurfer83\n ---\n \n Published using OSMCha: https://osmcha.org/changesets/182957594\n
#> 28 Moin Guenni :)\n\nGebäude und Wege sollten in Hessen auch immer mit dem ALKIS und dem DOP abgeglichen werden (beides in JOSM verfügbar). Diese sind idR besser ausgerichtet und auch gut aufgelöst.\n\nGrüße\nsilversurfer83\n ---\n \n Published using OSMCha: https://osmcha.org/changesets/182963343\n
#> 29 Dankeschön. Von der Zufahrt zum Skatepark hab ich nur noch das tracktype entfernt (ist eher für Feldwege) und das emergency hinzugefügt. Das ist zwar fast obsolet, da Rettungsfahrzeuge auch auf Fußwegen etc. fahren dürfen, aber da das Schild nun mal extra da steht ... ;-)\n\nVon mir auch danke für die gute Diskussion und ein schönes langes WE
#> 30 Partially reverted in changeset id: 183054534
#> 31 Hi :)\n\nwäre bei den einzelnen Solarflächen nicht power=generator angebrachter? Und dann entweder eine Fläche um alle Solarzellen ziehen und diese mit power=plant oder die einzelnen Zellen in einer Site-Relation zu einer power=plant zusammenfassen.\n\nGrüße\n\nsilversurfer83\n ---\n \n Published using OSMCha: https://osmcha.org/changesets/182965462\n
#> 32 Hei. Jeg ser at du har endret highway=cycleway + foot=designated til highway=cycleway + foot=yes + bicycle=yes på mange steder. Opprinnelig tagging er i tråd med dokumentert taggemåte på norsk wiki. Hvorfor endrer du?
#> 33 Hi :)\n\ndas Wiki sagt, dass wir um einzeln erfasste amenity=parking_space immer eine Fläche mit amenity=parking legen sollen. \n\nKleiner Hinweis zu deinem Editor: Es sollte eine Taste geben, die dir weitere Werkzeuge zeigt, wenn du ein Objekt ausgewählt hast. Da sollte eine Möglichkeit zu finden sein, ein Objekt rechtwinklig (oder rund) zu machen. Grad bei Gebäuden oder Parkplätzen sehr nützlich um schöne Geometrien zu erhalten.\n\nhappy mapping :)\n ---\n \n Published using OSMCha: https://osmcha.org/changesets/182993898\n
#> 34 Здравствуйте. Сомнительно, что супермаркет (большой магазин) находится в маленьком здании. \n \nhttps://wiki.openstreetmap.org/wiki/RU:Tag:shop%3Dsupermarket
#> 35 Czyli Starostwo Powiatowe w Pruszkowie zaproponowało przetarg? ;-)
#> 36 Moin heinz51walter :)\n\nda ich nicht in deinen Kopf schauen kann, hier eine kleine Erklärung zweier Eigenschaften nur für den Fall, dass du etwas verwechselt hast:\n\nnote=* ist als Hinweis für andere Mapper*innen gedacht und wird in praktisch keiner Karte für Endnutzer*innen angezeigt. \n\ndescription=* ist ein Freitextfeld um eine Beschreibung des Objekts zu hinterlassen, die auch von vielen Apps/Kartendiensten den Menschen angezeigt wird, die sich eine Karte ansehen.\n\nHappy mapping\n ---\n \n Published using OSMCha: https://osmcha.org/changesets/182946875\n
#> 37 Hmm, I'm a bit hesitant if this is the best way to represent the current layout at Cambie+KingEd. Because those two bike paths aren't properly connected to the road, the two cycleway links seem to suggest a somewhat unsafe movement that those bike paths are probably not built for. I'm not sure it's a good idea to map those movements until the work is done and we know for sure what the intended movements are for those.\n\nIt seems like the current use of those two bike paths is actually to act as temporary sidewalks, at least for those tiny segments right next to the corner. Because it is usually prohibited to cycle in sidewalks, I added "bicycle=no", which is a bit unorthodox for "highway=cycleway". Maybe it would be better to change those to "bicycle=dismount" instead?\n\nI made a revision to this area in changeset/183053444; feel free to let me know your thoughts!
#> 38 Hej\nJag anser att det är lämpligt att info om kommande öppning finns med i namnet eftersom startdate sällan visas eller respekteras i kartappar (utan nog är mer som tänkt historisk info)\nJag tänker så här: Du letar efter en Ica och hittar denna, men den har inte ens öppnat. Att ens lägga in affärer som inte öppnat kan också diskuteras eftersom OSM ska visa vad som finns i verkligheten.
#> 39 Welkom bij OpenStreetMap. Ik heb een uitgebreid welkomstbericht met wat handige tips en links gestuurd als privebericht.\nFeedback Wanneer je er niet mag fietsen en er een ruiterverbod is lijkt het mij oke.\nHet vervolg is trouwens als footway getagd?\nOp de slagboom staat weer bicycle=yes?\nMVG,\nEggie\nNamens de OSM Community\n\n\n
#> 40 https://www.openstreetmap.org/changeset/183053390
#> 41 FYI I demoted Kam Ho Road south of Pat Heung Road back to `=unclassified`.
#> 42 Здравствуйте. "Полетели72 - Полёты на Воздушном шаре в Тюмени" - это не название с точки зрения OpenStreetMap. \n \nhttps://wiki.openstreetmap.org/wiki/RU:Названия \n \nИ это место не магазин подарков. \n \nhttps://wiki.openstreetmap.org/wiki/RU:Tag:shop%3Dgift
#> 43 Здравствуйте. В названиях улиц указывают слово "улица", например "улица Александра Гилёва". \n \nhttps://wiki.openstreetmap.org/wiki/RU:Россия/Соглашение_об_именовании_дорог
#> 44 Zauważyłem, że Twoja zmiana zawiera adresy wymagające dodatkowej uwagi. Przygotowałem listę obiektów oraz dodatkowe informacje:\n\nNazwa ulicy nie istnieje w okolicy. Jeśli adres ma nazwę ulicy, upewnij się, że jest ona poprawna. Jeśli nie, usuń addr:street, a nazwę miejscowości przekaż w addr:place.\nhttps://www.openstreetmap.org/node/13864939260\n\nDokumentacja adresów (po polsku):\nhttps://wiki.openstreetmap.org/wiki/Pl:Key:addr:*\n\nW razie problemów lub pytań, proszę pisać. Chętnie pomogę.\nPozdrawiam! 🦀
#> 45 When will you use useful changeset comments? https://wiki.openstreetmap.org/wiki/Good_changeset_comments
#> 46 Revert, da keine Antwort.\n\nHallo Filderalex, ich vermute, dass das Löschen des Stolpersteins ein Versehen war, ebenso wie bei https://www.openstreetmap.org/node/11530933476/history\n\nIch habe daher die beiden Stolpersteine wieder hergestellt. Sollten die Stolpersteine tatsächlich nicht mehr vorhanden sein, dann gib bitte Bescheid für weitere Nachforschungen.\n\nViele Grüße, Joachim
#> 47 Reverted due SEO spam: self-promotion and suspicious changes\n\nhttps://www.openstreetmap.org/changeset/183051851
#> 48 Omleidingen tm 31-12-26, route loopt niet meer door Kockengen
#> 49 Omleidingen tm 31-12-26, route loopt niet meer door Kockengen
#> 50 Hi,\n\nIf you're going to add businesses to OSM for your clients, you have an obligation (to both your client and to us) to at least make every reasonable effort to use correct tags and values. The POI's website=* is inexplicably listed under brand=* instead and a spurious "Suite" is included in addr:street=*, which both pollutes the map with junk data and means it will not be intelligible to data consumers reading the map, defeating the purpose of your efforts here.\n\nIt's not really that difficult to use iD's beginner-friendly presets to fill in this information correctly, or spend a few minutes reading the wiki on how to format your tags properly. After all, you are being paid to do this properly for your client.\n\nFor now, I fixed both for you in changeset 183051753\n\nhttps://www.openstreetmap.org/changeset/183051753
#> 51 Untuk fitur penggunaan lahan atau tutupan lahan, praktiknya tidak boleh ditempelkan ke jalan atau batas administrasi. Dalam iD editor bisa disembunyikan fiturnya dengan tekan tombol U.
#> 52 Reverted due SEO spam: just a bare name=* on a building\n\nhttps://www.openstreetmap.org/changeset/183051663
#> 53 Hi,\n\nIf you're going to add businesses to OSM for your clients, you have an obligation (to both your client and to us) to at least make every reasonable effort to use correct tags and values. Many of the tags added here (address, opening_hours=*, phone=* website=*) are used incorrectly to the point of being essentially nonsense, which both pollutes the map with junk data and means they will not be intelligible to data consumers reading the map, defeating the purpose of your efforts here.\n\nIt's not really that hard to use iD's beginner-friendly presets to fill in this information correctly, or spend a few minutes reading the wiki on how to format your tags properly. After all, you are being paid to do this properly for your client. While it is your responsibility to fix this, I went ahead and did it for you in changeset 183051556\n\nhttps://www.openstreetmap.org/changeset/183051556
#> 54 Suntingan telah dipulihkan https://www.openstreetmap.org/changeset/183051483\n\nGunakan tutorial interaktif di iD editor jika pemula.
#> 55 Reverted due SEO spam: surveillance camera distributor mistagged as an actual surveillance camera\n\nhttps://www.openstreetmap.org/changeset/183051452
#> 56 Fixed nonsensical address tags and removed name nad address of individual unit from entire building in changeset 183051369\n\nhttps://www.openstreetmap.org/changeset/183051369
#> 57 Reverted due to adding a SEO spam POI with just a malformed name=* and image=* tag\n\nhttps://www.openstreetmap.org/changeset/183051273
#> 58 HTML/iframe injection attempting JavaScript execution via OSM tag.\n\nShould be reverted.
#> 59 HTML/iframe injection attempting JavaScript execution via OSM tag.\n\nShould be reverted.
#> 60 HTML/iframe injection attempting JavaScript execution via OSM tag.\n\nShould be reverted.
#> 61 HTML/iframe injection attempting JavaScript execution via OSM tag.\n\nShould be reverted.
#> 62 HTML/iframe injection attempting JavaScript execution via OSM tag.\n\nShould be reverted.
#> 63 D'accord, pas de soucis. De toute façon, il faut bien débuter et il n'est pas rare de "casser" des choses en faisant et en apprenant. On est tous passé par là.\n\nJe pense que pour ce cas là, pas besoin de faire de revert, tu pourras refaire manuellement quand tu as le temps. L'escalier avait ces tags associés avant que tu fasses la modif : \nhandrail=no\nhighway=steps\nincline=down\nstep_count=15\nsurface=ground\ntactile_paving=no
#> 64 Moin, ich habe die Anpassungen nach bestem Wissen eingepflegt. Hoffe ich hab alles so weit korrekt übernommen.\n\nZu https://www.openstreetmap.org/way/1333768770\nDie Regelung ändert sich ab dem Skatepark nicht - zumindest nicht durch Verkehrszeichen ersichtich.\nDie Beschilderung aus Richtung Norden lässt sich aktuell nicht ermitteln, da dort momentan eine Baustelle ist.
#> 65 Partially reverted in changeset id: 183050733
#> 66 Dag Sas,\nAl die accesstags zijn gewoon default op wegen. Ik heb ze verwijderd en de straatnaam weer toegevoegd. Die had je verwijderd.\n\nMVG\neggie
#> 67 Hi, Welcome to OpenStreetMap.\n\nThe OSM tags in this case would be:- loc_name=St Mark's Park\nofficial_name=Kensington Memorial Park\n\nRegards Bernard.
#> 68 https://www.openstreetmap.org/changeset/183050292
#> 69 Ciao, perché c'è il cartello "divieto di transito" (access=no) ma "eccetto autorizzati" (access=private). Questo cartello si applica a tutti i veicoli guidati dall'uomo, quindi anche bici e cavalli. Pensavo si applicasse anche ai pedoni ma ho appena ricontrollato e non è così, perciò ho aggiunto foot=yes.
#> 70 Partially reverted in changeset id: 183050283
#> 71 ...and teach your colleagues to do the same!
#> 72 Thank you for not commenting again. \nNext time, I will add some sources that you or other might delete it.
#> 73 in Jayapura
#> 74 Ervin Joshua Del Rosario, your changes don't make sense. I am trying to see what you did in these changesets but you made too many of them.
#> 75 Great work on all the detailed mapping around here!\n\nStory. A few years back I random-camped across the road, unaware of the gravel pit. Suddenly at 7am, I was aware - gravel crushing! I left quickly, drove off and brewed my coffee at a wide spot on the road with a view.
#> 76 Rottler Brillen ist shop=optician, nicht healthcare=optometrist.\nIch schätze mal, die Übersetzung in StreetComplete ist da nicht gut und zeigt beides als "Optiker" an.\n\nKorrigiert in https://www.openstreetmap.org/changeset/183048639
#> 77 https://wiki.openstreetmap.org/wiki/Australian_Tagging_Guidelines/Cycling_and_Foot_Paths#Mountain_biking_and_BMX\n\nAlthough we do list the informal mtb track there as bicycle=designated, I think we should probably change that, but keen to hear what others think.
#> 78 I'm not sure. Usually I'd reserve bicycle=designated for paths explicitly/officially designated for bicycles via signage. Being an access tag, bicycle=designated implies the highest indication that bicycles are permitted and intended to use the trail. \n\nThese trails are on crown lands and seem to be informal as they are are not officially maintained or endorsed/approved.\n\nTherefore I would use\n\n1. highway=path + path=mtb (to indicate the path is constructed/built as a mountain bike track, noted by the curve banks, small jumps etc)\n2. informal=yes the path is not formally endorsed, it's just informal.\n3. bicycle=yes bicycles seem to be tolerated, there's no "no bicycles" signage, but at the same time they aren't explicitly indicated (compare this to the nearby Serrata and Gahnia tracks)
#> 79 Hallo gpermant,\nüblicherweise werden Objekte, die eine bauliche Veränderung erfahren mit dem Zusatz Präfix (https://wiki.openstreetmap.org/wiki/DE:Lebenszyklus-Pr%C3%A4fix) ausgestattet. Durch den Präfix kann sichergestellt werden, dass Objekte, die es noch nicht gibt oder die verfallen, geschlossen oder entfernt wurden, von Renderern und Anwendungen anders als existente Objekte behandelt werden. Das Gebäude wird noch lange ohne erkennbare Informationen auf diversen Karten erkennbar sein und gerne von Ortsunkundigen erneut erfasst. \nVG pitfire\n
#> 80 Please note the Australian phone format\nhttps://wiki.openstreetmap.org/wiki/Australian_Tagging_Guidelines/Australian_features\nI have fixed these two changeset phones
#> 81 Hello, this looks like part of an organized edit. Could you provide a link to the organized edit page on the wiki?
#> 82 Partially reverted in changeset id:183047410
#> 83 Revert of 182856682
#> 84 Revert vandalism. Incorrect street classification.
#> 85 Thanks for the feedback! I do personally believe it’s more of a highway=pedestrian than a highway=footway, but feel free to implement changes as you see fit, as I am only one person and my interpretations aren’t what everyone would do.
#> 86 Hello Supaplex,\nIn Germany it is common that the place is sufficient as a change comment. In Taiwan it is difficult with the location names, so I used "Update Taiwan" for myself. I have already commented on the last change in more detail, if this is more common in Taiwan. Regards, ocrho
#> 87 I would say that https://www.openstreetmap.org/way/49903202 needs to be split. The portion in the caravan park is permissive, but from the beach up to the walking/cycle track is public.\n ---\n \n Published using OSMCha: https://osmcha.org/changesets/183001676\n
#> 88 Most of these edits are great! However please be careful when applying the editor's recommended changes, they are not always correct. For example:\n\nhttps://www.openstreetmap.org/way/391487047\n\nThe Hi-Lo hotel is not associated with Hostelling International\n\nhttps://www.openstreetmap.org/way/339789636\n\nThese parking lots are private employee parking, not park-and-ride lots.
#> 89 Some questionable issues regarding your edits:\n1. You've acknowledged that repeatedly moving the same node across dozens of changesets due to the zooming limits of iD was "disruptive editing", and stated that you would stop to do so (https://www.openstreetmap.org/changeset/182710040#c1595671). The block on this account (https://www.openstreetmap.org/user_blocks/20523) was subsequently lifted. However, it appears that you've continued to make similar edits: you moved node/13855959408 20 times, node/13851785391 34 times, node/13850632009 11 times, and node/13836987920 55 times.\n2. Your edits regarding the so-called "Philippine Exclusive Economic Zone" are completely based on your own assumptions. Your edits appear to join the lines with the outer limit of the territorial waters of the Philippine occupied islets. This is completely incorrect and does not reflect the claim of any side.\n3. Malaysia and the Philippines claim waters extending 200 nm from their baselines as their exclusive economic zone. China has never announced the delimitation of the territorial waters, exclusive economic zone, and continental shelves around the Nansha (Spratly) Islands, but China describes the waters close to the Philippines as the "overlapping waters of China-Philippines exclusive economic zones". This means that any claims regarding the exclusive economic zone in this area are unilateral, which does not constitute a mutually recognized final delimitation.\n4. The outer boundaries of the exclusive economic zone should not be tagged with admin_level=2 + border_type=territorial + boundary=administrative. A state's sovereignty extends over its territory, internal waters, and territorial sea. Sovereign rights in the exclusive economic zone do not constitute full sovereignty.\n5. Territorial waters are not included in the exclusive economic zone, but it appears that you included the territorial water delimitations as the outer boundaries of the exclusive economic zones.\n6. You are not supposed to add the admin_centre member into boundary=maritime .\n7. You should not assign the inner members with the outer roles in a type=boundary relation.
#> 90 small update-\n\nAfter some back-and-forth, it seems like NAPR is completely unenthusiastic about clarifying the license and the age of the data they're providing via the "base" layer. The work's actually been sponsored by the EU members and was completed in 2022. It's pretty safe to assume nothing's got updated since then (and the EU stopped the allocations), which practically sets the age of that data to at least 5 years old.\n\nI understand that the map would be empty without the cadastral data, but given the circumstances, I'd suggest relying more on personal experience when populating the map. Thanks.
#> 91 Thanks for the review! Revised accordingly.\n\nI was originally operating based on wiki guidance that access tags should describe legal constraints, independent of physical constraints (which might be tagged separately), but DNR rules explicitly forbid cars here anyway so it works out the same.\n ---\n \n Published using OSMCha: https://osmcha.org/changesets/182807275\n
#> 92 Hi, thanks for updating this development. Just a note to say I've adjusted how the named area of Great Milton Park is laid out. The relation you created (https://www.openstreetmap.org/relation/20657648) still covers the whole area, but I have moved landuse=residential onto smaller polygons so as to exclude roads and non-residential areas. A second note, when you are tracing buildings, you can use 'Q' to square the corners, this will make them look neater and be more accurate. If you have any questions or problems, feel free to ask :).
#> 93 Strictly speaking I did copy these from objects that originated from the given 'source:*'. Does that mean that, in fact, we should retain the source information on them?\n\nThe list of object IDs is:\n\nw:1518988409\nw:1518988410\nw:1518988411\nw:1518988412\nw:1518988413\nw:1518988414\nw:1518988415\nw:1518988416\nw:1518988417\nw:1518988418\nw:1518988419\nw:1518988420\nw:1518988421\nw:1518988422\nw:1518988423\nw:1518988424\nw:1518988425\nw:1518988426\nw:1518988427\nw:1518988428\nw:1518988429\nw:1518988430\nw:1518988431\nw:1518988432\nw:1518990293
#> 94 FIgured it's a trunk due to: Favor a route which has the "best" continuity / connective value to the rest of the road network\nFavor higher-speed bypasses built to allow through traffic faster passage through built-up area
#> 95 Buildings added by this changeset were copy-pasted; their "source:*" tags are therefore inaccurate. I realised this while continuing another area.\n\nI'll try to figure out how to batch delete those tags soon.
#> 96 Feel free to change the data you disagree with, thank you
#> 97 Has there been any discussion to support further changes to maritime boundaries here? (Your previous edits were already reverted.) You have also changed the border of Spain despite not mentioning this in your changeset comment.
#> 98 forgot to link it in the changeset as a source but the video used is https://www.youtube.com/watch?v=gjkPDpig6IA
#> 99 Please upload business as separate change.\n\nI recommend you read the section on splitting geographically large changesets. https://wiki.openstreetmap.org/wiki/Changeset\n\nThanks!
#> 100 East Indiana is not primary -- not even close. Seven years ago, before it got narrowed to one lane each way, it saw maybe 20% the traffic of the Division-Ruby couplet. Traffic has fallen since then.\n\nMore generally, if everything is important, then nothing is. As things stand right now, there's nothing to distinguish Division/Ruby (50k vehicles/day) from Maple/Ash (40k) from Hamilton (30k) from Washington (20k) from Monroe (17k).
# Search for changeset comments by a specific user:
osm_search_comment_changeset_discussion(user = "Steve", format = "json")
#> $version
#> [1] "0.6"
#>
#> $generator
#> [1] "OpenStreetMap server"
#>
#> $copyright
#> [1] "OpenStreetMap and contributors"
#>
#> $attribution
#> [1] "http://www.openstreetmap.org/copyright"
#>
#> $license
#> [1] "http://opendatacommons.org/licenses/odbl/1-0/"
#>
#> $comments
#> $comments[[1]]
#> $comments[[1]]$id
#> [1] 664366
#>
#> $comments[[1]]$visible
#> [1] TRUE
#>
#> $comments[[1]]$date
#> [1] "2021-02-25T19:31:46Z"
#>
#> $comments[[1]]$uid
#> [1] 1
#>
#> $comments[[1]]$user
#> [1] "Steve"
#>
#> $comments[[1]]$text
#> [1] "woo!"
#>
#>
#>
# Search for changeset comments between January 1st and January 2nd, 2015:
osm_search_comment_changeset_discussion(from = "2015-01-01", to = "2015-01-02", format = "xml")
#> {xml_document}
#> <osm version="0.6" generator="OpenStreetMap server" copyright="OpenStreetMap and contributors" attribution="http://www.openstreetmap.org/copyright" license="http://opendatacommons.org/licenses/odbl/1-0/">
#> [1] <comment id="3597" date="2015-01-01T23:41:30Z" visible="true" uid="10915 ...
#> [2] <comment id="3596" date="2015-01-01T23:36:36Z" visible="true" uid="88164 ...
#> [3] <comment id="3595" date="2015-01-01T23:29:40Z" visible="true" uid="88164 ...
#> [4] <comment id="3594" date="2015-01-01T23:24:27Z" visible="true" uid="61942 ...
#> [5] <comment id="3593" date="2015-01-01T23:19:58Z" visible="true" uid="88164 ...
#> [6] <comment id="3592" date="2015-01-01T23:15:54Z" visible="true" uid="23858 ...
#> [7] <comment id="3591" date="2015-01-01T23:15:38Z" visible="true" uid="39688 ...
#> [8] <comment id="3590" date="2015-01-01T23:12:25Z" visible="true" uid="61942 ...
#> [9] <comment id="3589" date="2015-01-01T22:23:35Z" visible="true" uid="61942 ...
#> [10] <comment id="3588" date="2015-01-01T22:14:08Z" visible="true" uid="61942 ...
#> [11] <comment id="3587" date="2015-01-01T21:53:43Z" visible="true" uid="18850 ...
#> [12] <comment id="3586" date="2015-01-01T21:53:40Z" visible="true" uid="61942 ...
#> [13] <comment id="3585" date="2015-01-01T21:29:38Z" visible="true" uid="33121 ...
#> [14] <comment id="3584" date="2015-01-01T20:30:27Z" visible="true" uid="25485 ...
#> [15] <comment id="3583" date="2015-01-01T19:49:08Z" visible="true" uid="23858 ...
#> [16] <comment id="3582" date="2015-01-01T19:40:03Z" visible="true" uid="12992 ...
#> [17] <comment id="3581" date="2015-01-01T19:39:16Z" visible="true" uid="12992 ...
#> [18] <comment id="3580" date="2015-01-01T17:53:47Z" visible="true" uid="13112 ...
#> [19] <comment id="3579" date="2015-01-01T16:35:02Z" visible="true" uid="10915 ...
#> [20] <comment id="3578" date="2015-01-01T16:23:43Z" visible="true" uid="61942 ...
#> ...